@@ -107,8 +107,7 @@ public:
 	void addPlayer(Player *player);
 	void removePlayer(Player *player);
 	
-	QPtrList<Player> players() const;
-	unsigned int acceptCount();
+	unsigned int count( bool acceptOnly );
 
 	bool isRejected() { return m_rejected; }
 	
@@ -118,11 +117,11 @@ public:
 	 **/
 	template <class Type> Type *select(Player *from, Player *to)
 	{
-		for (QPtrListIterator<Player> i(mPlayers()); *i; ++i)
+		for (QPtrListIterator<Player> i(mPlayers); *i; ++i)
 		{
 			if (
-					(*i)->from()==from
-					&& (*i)->to()==to
+					i.current()->from()==from
+					&& i.current()->to()==to
 					&& dynamic_cast<Player*>(*i)
 				)
 			{
