@@ -1,4 +1,4 @@
-// Copyright (c) 2002-2003 Rob Kaper <cap@capsi.com>
+// Copyright (c) 2002-2004 Rob Kaper <cap@capsi.com>
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -126,7 +126,7 @@ EstateView *AtlantikBoard::findEstateView(Estate *estate)
 void AtlantikBoard::addEstateView(Estate *estate, bool indicateUnowned, bool highliteUnowned, bool darkenMortgaged, bool quartzEffects)
 {
 	QString icon = QString();
-	int estateId = estate->estateId();
+	int estateId = estate->id();
 	EstateOrientation orientation = North;
 	int sideLen = m_gridLayout->numRows() - 1;
 
@@ -195,24 +195,23 @@ Token *AtlantikBoard::findToken(Player *player)
 
 void AtlantikBoard::addToken(Player *player)
 {
-	kdDebug() << "addToken" << endl;
 	if (!player->location())
 	{
-		kdDebug() << "addToken - estateView null" << endl;
+		kdDebug() << "addToken ignored - estateView null" << endl;
 		return;
 	}
 
-	Player *playerSelf = m_atlanticCore->playerSelf();
-	if (playerSelf)
+	Player *playerSelf = 0;
+	if (m_atlanticCore)
+		playerSelf = m_atlanticCore->playerSelf();
+
+	if (playerSelf && playerSelf->game() != player->game() )
 	{
-		if (playerSelf->gameId() != player->gameId())
-		{
-			kdDebug() << "addToken - not in same game" << endl;
-			return;
-		}
+		kdDebug() << "addToken ignored - not in same game as playerSelf" << endl;
+		return;
 	}
-	else
-		kdDebug() << "addToken - no playerSelf" << endl;
+
+	kdDebug() << "addToken" << endl;
 
 	Token *token = new Token(player, this, "token");
 	m_tokens.append(token);
@@ -226,13 +225,18 @@ void AtlantikBoard::addToken(Player *player)
 
 void AtlantikBoard::playerChanged(Player *player)
 {
-	Player *playerSelf = m_atlanticCore->playerSelf();
+	kdDebug() << "playerChanged: playerLoc " << (player->location() ? player->location()->name() : "none") << endl;
+
+	Player *playerSelf = 0;
+	if (m_atlanticCore)
+		playerSelf = m_atlanticCore->playerSelf();
 
 	// Update token
 	Token *token = findToken(player);
 	if (token)
 	{
-		if (player->isBankrupt() || (playerSelf && playerSelf->gameId() != player->gameId()) )
+		kdDebug() << "playerChanged: tokenLoc " << (token->location() ? token->location()->name() : "none") << endl;
+		if (player->isBankrupt() || (playerSelf && playerSelf->game() != player->game()) )
 			token->hide();
 		if (player->hasTurn())
 			token->raise();
@@ -242,7 +246,12 @@ void AtlantikBoard::playerChanged(Player *player)
 		if (token->inJail() != player->inJail())
 		{
 			token->setInJail(player->inJail());
-			jump = true;
+
+			// If any status such as jail is ever allowed to
+			// change in the future, during movement, this needs
+			// to be addressed in moveToken and subsequent steps.
+			if (token != m_movingToken)
+				jump = true;
 		}
 			
 		if (token->location() != player->location())
@@ -265,10 +274,10 @@ void AtlantikBoard::playerChanged(Player *player)
 			}
 		}
 
-		if (jump)
-			jumpToken(token);
 		if (move)
 			moveToken(token);
+		else if (jump)
+			jumpToken(token);
 	}
 	else
 		addToken(player);
@@ -312,7 +321,9 @@ void AtlantikBoard::jumpToken(Token *token)
 	if (token == m_movingToken)
 	{
 		m_timer->stop();
-		m_movingToken = 0;
+
+		if (!m_resumeTimer)
+			m_movingToken = 0;
 	}
 
 	emit tokenConfirmation(token->location());
@@ -368,6 +379,13 @@ QPoint AtlantikBoard::calculateTokenDestination(Token *token, Estate *eDest)
 
 void AtlantikBoard::slotMoveToken()
 {
+	// Requires a core with estates to operate on
+	if (!m_atlanticCore)
+	{
+		kdDebug() << "slotMoveToken ignored - no atlanticCore" << endl;
+		return;
+	}
+
 	// Do we actually have a token to move?
 	if (!m_movingToken)
 	{
@@ -538,18 +556,36 @@ void AtlantikBoard::prependEstateDetails(Estate *estate)
 	if (!estate)
 		return;
 
-	EstateDetails *eDetails = new EstateDetails(estate, QString::null, this);
+	EstateDetails *eDetails = 0;
+
+	if (m_displayQueue.getFirst() == m_lastServerDisplay)
+	{
+		eDetails = new EstateDetails(estate, QString::null, this);
+		m_displayQueue.prepend(eDetails);
+
+		connect(eDetails, SIGNAL(buttonCommand(QString)), this, SIGNAL(buttonCommand(QString)));
+		connect(eDetails, SIGNAL(buttonClose()), this, SLOT(displayDefault()));
+	}
+	else
+	{
+		eDetails = dynamic_cast<EstateDetails*> ( m_displayQueue.getFirst() );
+		if (eDetails)
+		{
+			eDetails->setEstate(estate);
+			eDetails->setText( QString::null );
+			// eDetails->clearButtons();
+		}
+		else
+		{
+			kdDebug() << "manual estatedetails with first in queue neither server nor details" << endl;
+			return;
+		}
+	}
+
+	eDetails->addDetails();
 	eDetails->addCloseButton();
 
-	if (m_displayQueue.getFirst() != m_lastServerDisplay)
-		m_displayQueue.removeFirst();
-
-	m_displayQueue.prepend(eDetails);
 	updateCenter();
-
-	connect(eDetails, SIGNAL(buttonCommand(QString)), this, SIGNAL(buttonCommand(QString)));
-	connect(eDetails, SIGNAL(buttonClose()), this, SLOT(displayDefault()));
-
 }
 
 void AtlantikBoard::updateCenter()
