@@ -31,6 +31,8 @@
 
 #include "token.moc"
 
+#define ICONSIZE	32
+
 Token::Token(Player *player, AtlantikBoard *parent, const char *name) : QWidget(parent, name)
 {
 	setBackgroundMode(NoBackground); // avoid flickering
@@ -47,7 +49,16 @@ Token::Token(Player *player, AtlantikBoard *parent, const char *name) : QWidget(
 	qpixmap = 0;
 	b_recreate = true;
 
-	setFixedSize(QSize(26, 26));
+	// Init icon
+	m_image = 0;
+	loadIcon();
+
+	setFixedSize(QSize(ICONSIZE, ICONSIZE + KGlobalSettings::generalFont().pointSize()));
+}
+
+Token::~Token()
+{
+	delete m_image;
 }
 
 Player *Token::player()
@@ -69,25 +80,71 @@ void Token::setDestination(Estate *estateView)
 
 void Token::playerChanged()
 {
+	if (m_imageName != m_player->image())
+		loadIcon();
+
 	b_recreate = true;
 	update();
 }
 
+void Token::loadIcon()
+{
+	m_imageName = m_player->image();
+
+	delete m_image;
+	m_image = 0;
+
+	if (!m_imageName.isEmpty())
+	{
+		QString filename = locate("data", "atlantik/themes/default/tokens/" + m_imageName);
+		if (KStandardDirs::exists(filename))
+			m_image = new QPixmap(filename);
+	}
+
+	if (!m_image)
+	{
+		m_imageName = "hamburger.png";
+
+		QString filename = locate("data", "atlantik/themes/default/tokens/" + m_imageName);
+		if (KStandardDirs::exists(filename))
+			m_image = new QPixmap(filename);
+	}
+
+	QWMatrix m;
+	m.scale(double(ICONSIZE) / m_image->width(), double(ICONSIZE) / m_image->height());
+	QPixmap *scaledPixmap = new QPixmap(ICONSIZE, ICONSIZE);
+	*scaledPixmap = m_image->xForm(m);
+
+	delete m_image;
+	m_image = scaledPixmap;
+}
+
 void Token::paintEvent(QPaintEvent *)
 {
 	if (b_recreate)
 	{
 		delete qpixmap;
-		qpixmap = new QPixmap(locate("data", "atlantik/pics/token.png"));
+		qpixmap = new QPixmap(width(), height());
 
 		QPainter painter;
 		painter.begin(qpixmap, this);
 
-		painter.drawPixmap(0, 0, *qpixmap);
+        if (m_image)
+		{
+			painter.setPen(Qt::black);
+			painter.setBrush(Qt::white);
+			painter.drawRect(0, 0, ICONSIZE, ICONSIZE);
+
+			painter.drawPixmap(0, 0, *m_image);
+		}
 
 		painter.setPen(Qt::black);
-		painter.setFont(QFont(KGlobalSettings::generalFont().family(), KGlobalSettings::generalFont().pointSize(), QFont::Bold));
-		painter.drawText(2, height()-2, (m_player ? m_player->name() : QString::null));
+		painter.setBrush(Qt::black);
+		painter.drawRect(0, ICONSIZE, width(), KGlobalSettings::generalFont().pointSize());
+
+		painter.setPen(Qt::white);
+		painter.setFont(QFont(KGlobalSettings::generalFont().family(), KGlobalSettings::generalFont().pointSize(), QFont::DemiBold));
+		painter.drawText(1, height()-1, (m_player ? m_player->name() : QString::null));
 
 		b_recreate = false;
 	}
