@@ -72,7 +72,7 @@ TradeDisplay::TradeDisplay(Trade *trade, AtlanticCore *atlanticCore, QWidget *pa
 	{
 		if ((estate = *it) && estate->isOwned())
 		{
-			m_estateCombo->insertItem(estate->name());
+			m_estateCombo->insertItem( PortfolioEstate::drawPixmap(estate), estate->name() );
 			m_estateMap[m_estateCombo->count() - 1] = estate;
 			m_estateRevMap[estate] = m_estateCombo->count() - 1;
 		}
@@ -83,7 +83,7 @@ TradeDisplay::TradeDisplay(Trade *trade, AtlanticCore *atlanticCore, QWidget *pa
 	m_moneyBox = new QSpinBox(0, 10000, 1, m_updateComponentBox);
 
 	QPtrList<Player> playerList = m_atlanticCore->players();
-	Player *player;
+	Player *player, *pSelf = m_atlanticCore->playerSelf();
 
 	m_fromLabel = new QLabel(m_updateComponentBox);
 	m_fromLabel->setText(i18n("From"));
@@ -95,7 +95,7 @@ TradeDisplay::TradeDisplay(Trade *trade, AtlanticCore *atlanticCore, QWidget *pa
 
 	for (QPtrListIterator<Player> it(playerList); *it; ++it)
 	{
-		if ((player = *it))
+		if ((player = *it) && player->game() == pSelf->game())
 		{
 			m_playerFromCombo->insertItem(player->name());
 			m_playerFromMap[m_playerFromCombo->count() - 1] = player;
@@ -118,7 +118,7 @@ TradeDisplay::TradeDisplay(Trade *trade, AtlanticCore *atlanticCore, QWidget *pa
 	listCompBox->addWidget(m_componentList);
 
 	m_componentList->addColumn(i18n("Player"));
-	m_componentList->addColumn(i18n("gives"));
+	m_componentList->addColumn(i18n("Gives"));
 	m_componentList->addColumn(i18n("Player"));
 	m_componentList->addColumn(i18n("Item"));
 
@@ -143,7 +143,7 @@ TradeDisplay::TradeDisplay(Trade *trade, AtlanticCore *atlanticCore, QWidget *pa
 
 	m_status = new QLabel(this);
 	listCompBox->addWidget(m_status);
-	m_status->setText(i18n("%1 out of %2 players accept current trade proposal.").arg(m_trade->acceptCount()).arg(m_trade->players().count()));
+	m_status->setText( i18n( "%1 out of %2 players accept current trade proposal." ).arg( m_trade->count( true ) ).arg( m_trade->count( false ) ) );
 
 //	mPlayerList->header()->hide();
 //	mPlayerList->setRootIsDecorated(true);
@@ -196,6 +196,7 @@ void TradeDisplay::tradeItemRemoved(TradeItem *t)
 {
 	KListViewItem *item = m_componentMap[t];
 	delete item;
+	m_componentMap[t] = 0;
 }
 
 void TradeDisplay::tradeItemChanged(TradeItem *t)
@@ -215,7 +216,7 @@ void TradeDisplay::tradeChanged()
 {
 	// TODO: add notification whether playerSelf has accepted or not and
 	// enable/disable accept button based on that
-	m_status->setText(i18n("%1 out of %2 players accept current trade proposal.").arg(m_trade->acceptCount()).arg(m_trade->players().count()));
+	m_status->setText( i18n( "%1 out of %2 players accept current trade proposal." ).arg( m_trade->count( true ) ).arg( m_trade->count( false ) ) );
 }
 
 void TradeDisplay::playerChanged(Player *player)
