@@ -59,9 +59,10 @@ class GameWidget : public QWidget
     // important labels : highest and current scores
     QLabel *hs, *ys;
     QString highest, current;
-    KScoreDialog *high;
-    
+
     int nlevels;
+
+    KScoreDialog *highScore;
 };
 
 #endif
