@@ -18,7 +18,7 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-  $Id: kbgfibschat.cpp,v 1.25 2003/07/26 23:09:34 mueller Exp $
+  $Id: kbgfibschat.cpp,v 1.26 2004/06/26 07:05:36 binner Exp $
 
 */
 
@@ -785,7 +785,7 @@ void KBgChat::slotSilent()
 {
     QString msg;
     if (((KToggleAction *)d->mAct[KBgChatPrivate::Silent])->isChecked())
-        msg = "<font color=\"blue\">" + i18n("You won't hear what people shout.") + "</font>";
+        msg = "<font color=\"blue\">" + i18n("You will not hear what people shout.") + "</font>";
     else
         msg = "<font color=\"blue\">" + i18n("You will hear what people shout.") + "</font>";
     addMessage(QString::null, msg);
