@@ -15,9 +15,9 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-  $Id: kbgengine.cpp,v 1.3 2001/09/20 02:58:01 hoefkens Exp $
+  $Id: kbgengine.cpp,v 1.5 2003/03/07 22:09:21 waba Exp $
 
 */
 
@@ -27,7 +27,7 @@
 #include <kdialogbase.h>
 
 #include <kbgengine.moc>
-#include <kbgengine.h>
+#include "kbgengine.h"
 
 
 /*
