@@ -15,9 +15,9 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-  $Id: kbgplayer.cpp,v 1.1 2001/08/16 21:13:25 hoefkens Exp $
+  $Id: kbgplayer.cpp,v 1.3 2003/03/07 22:09:21 waba Exp $
 
 */
 
@@ -26,7 +26,7 @@
 
 #include <kgame.h>
 
-#include <iostream.h>
+#include <iostream>
 
 
 /*
