@@ -17,7 +17,7 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-  $Id: kbg.cpp,v 1.35 2003/10/24 20:06:42 mhunter Exp $
+  $Id: kbg.cpp,v 1.38 2004/07/13 00:20:01 bmeyer Exp $
 
 */
 
@@ -39,7 +39,6 @@
 #include <ktoolbar.h>
 #include <kapplication.h>
 #include <kiconloader.h>
-#include <kkeydialog.h>
 #include <kedittoolbar.h>
 #include <klocale.h>
 #include <kaction.h>
@@ -131,11 +130,6 @@ KBg::KBg()
     cubeAction->setEnabled(false);
 
 	KStdAction::showMenubar(this, SLOT(toggleMenubar()),     actionCollection());
-	setStandardToolBarMenuEnabled(true);
-	createStandardStatusBarAction();
-
-	KStdAction::keyBindings(this, SLOT(configureKeys()), actionCollection());
-	KStdAction::configureToolbars(this,SLOT(configureToolbars()), actionCollection());
 	KStdAction::preferences(this, SLOT(setupDlg()), actionCollection());
 	KStdAction::saveOptions(this, SLOT(saveConfig()), actionCollection());
 
@@ -165,7 +159,8 @@ KBg::KBg()
 	 * Done with the actions, create the XML-defined parts of the
 	 * user interface
 	 */
-	createGUI();
+	statusBar();
+	setupGUI();
 
 	cmdLine->setFocus();
 
@@ -330,8 +325,6 @@ void KBg::saveConfig()
 		config->setGroup("main window");
 
 		config->writeEntry("origin", pos());
-		config->writeEntry("height", height());
-		config->writeEntry("width",  width());
 
 		config->writeEntry("font",   status->font());
 		config->writeEntry("panner", (double)board->height()/(double)panner->height());
@@ -379,8 +372,6 @@ void KBg::readConfig()
 		QFont kappFont = kapp->font();
 
 		pos = config->readPointEntry("origin", &defpos);
-		setGeometry(pos.x(), pos.y(), config->readNumEntry("width",520),
-			    config->readNumEntry("height",473));
 
 		status->setFont(config->readFontEntry("font", &kappFont));
 
@@ -693,14 +684,6 @@ void KBg::toggleMenubar()
 	}
 }
 
-/*
- * Display a standard dialog for key bindings
- */
-void KBg::configureKeys()
-{
-	KKeyDialog::configure(actionCollection(), this);
-}
-
 /*
  * Display a standard dialog for the toolbar content
  */
