@@ -14,9 +14,9 @@
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-  $Id: kbgstatus.h,v 1.7 2001/08/16 21:13:25 hoefkens Exp $
+  $Id: kbgstatus.h,v 1.9 2003/07/01 00:31:37 mueller Exp $
   
 */
 
@@ -41,7 +41,7 @@
  *
  * @short The backgammon status object
  * @author Jens Hoefkens <jens@hoefkens.com>
- * @version $Id: kbgstatus.h,v 1.7 2001/08/16 21:13:25 hoefkens Exp $
+ * @version $Id: kbgstatus.h,v 1.9 2003/07/01 00:31:37 mueller Exp $
  */
 class KBgStatus : public QObject
 {
@@ -62,7 +62,7 @@ class KBgStatus : public QObject
 	enum {Black = -1, White = +1};
 
 	/**
-	 * The default constructor intializes the status to an "empty" 
+	 * The default constructor initializes the status to an "empty" 
 	 * state. The board and dice are empty and the cube shows 1.
 	 */
 	KBgStatus();
