@@ -39,7 +39,6 @@
 #include "kbattleshipview.h"
 #include "kchatwidget.h"
 #include "kclientdialog.h"
-#include "khighscoredialog.h"
 #include "konnectionhandling.h"
 #include "kserverdialog.h"
 #include "kship.h"
@@ -60,7 +59,7 @@ public:
 	KShip *enemyShipAt(int fieldx, int fieldy);
 
 private slots:
-	void slotConfigureKeys();
+	void changeShipPlacementDirection();
 	void slotConfigureNotifications();
 	void slotLost(KMessage *msg);
 	void slotStatusMsg(const QString &text);
@@ -95,8 +94,8 @@ private slots:
 	void slotStartBattleshipGame(bool clearstat);
 	void slotStartBattleshipServer();
 	void slotConnectToBattleshipServer();
-	void slotPlaceShipPreview(int fieldx, int fieldy, bool shift);
-	void slotPlaceShip(int fieldx, int fieldy, int button);
+	void slotPlaceShipPreview(int fieldx, int fieldy);
+	void slotPlaceShip(int fieldx, int fieldy);
 	void slotChangeOwnFieldData(int fieldx, int fieldy, int type);
 	void slotChangeEnemyFieldData(int fieldx, int fieldy, int type);
 	void slotUpdateHighscore();
@@ -109,6 +108,7 @@ private slots:
 	void slotReceivedClientInformation(const QString &client, const QString &clientVersion, const QString &clientInformation, const QString &protocolVersion);
 
 private:
+	bool shift;
 	void initActions();
 	void initStatusBar();
 	void initView();
@@ -149,7 +149,6 @@ private:
 	KToggleAction *m_configGrid;
 	KClientDialog *m_client;
 	KServerDialog *m_server;
-	KHighscoreDialog *m_score;
 	KShipList *m_ownshiplist;
 	KShipList *m_enemyshiplist;
 	QString m_ownNickname;
