@@ -35,10 +35,8 @@ KBDiagonalWrapStrategy::KBDiagonalWrapStrategy(KBStrategy *parent) : KBStrategy(
 
 KBDiagonalWrapStrategy::~KBDiagonalWrapStrategy()
 {
-	if(m_child != 0)
-		delete m_child;
-	if(m_destroyer != 0)
-		delete m_destroyer;
+	delete m_child;
+	delete m_destroyer;
 }
 
 void KBDiagonalWrapStrategy::init(KBattleField *field, const QRect &field_rect)
@@ -46,8 +44,8 @@ void KBDiagonalWrapStrategy::init(KBattleField *field, const QRect &field_rect)
 	KBStrategy::init(field, field_rect);
 	KRandomSequence rand;
 
-	m_column = (int) rand.getLong(m_fieldRect.width() - 1);
-	m_row = (int) rand.getLong(m_fieldRect.height() - 1);
+	m_column = (int) rand.getLong(m_fieldRect.width());
+	m_row = (int) rand.getLong(m_fieldRect.height());
 
 	switch(rand.getLong(4))
 	{
@@ -122,7 +120,7 @@ bool KBDiagonalWrapStrategy::advance()
 			break;
 	}
 
-	return m_child->hasMoreShots();
+	return true;
 }
 
 bool KBDiagonalWrapStrategy::hasMoreShots()
