@@ -34,18 +34,16 @@ KBHorizontalStepStrategy::KBHorizontalStepStrategy(KBStrategy *parent) : KBStrat
 
 KBHorizontalStepStrategy::~KBHorizontalStepStrategy()
 {
-	if(m_child != 0)
-		delete m_child;
-	if(m_destroyer != 0)
-		delete m_destroyer;
+	delete m_child;
+	delete m_destroyer;
 }
 
 void KBHorizontalStepStrategy::init(KBattleField *field, const QRect &field_rect)
 {
 	KBStrategy::init(field, field_rect);
 	KRandomSequence rand;
-	m_column = (int) rand.getLong(m_fieldRect.width() - 1);
-	m_row = (int) rand.getLong(m_fieldRect.height() - 1);
+	m_column = (int) rand.getLong(m_fieldRect.width());
+	m_row = (int) rand.getLong(m_fieldRect.height());
 	m_start = QPoint(m_column, m_row);
 	m_passes = 0;
 
@@ -75,7 +73,7 @@ bool KBHorizontalStepStrategy::advance()
 	col = m_column;
 	row = m_row;
 
-	while(enemyFieldStateAt(col, row) == SHOT)
+	while(enemyFieldStateAt(col, row) == KBStrategy::SHOT)
 	{
 		col += 2;
 		if(col >= m_fieldRect.width())
@@ -85,10 +83,13 @@ bool KBHorizontalStepStrategy::advance()
 		}
 
 		if(col == m_start.x() && row == m_start.y())
+		{
+			col = (col + 1) % m_fieldRect.width();
 			row = (row + 1) % m_fieldRect.height();
+		}
 	}
 
-	if(enemyFieldStateAt(col, row) != SHOT)
+	if(enemyFieldStateAt(col, row) != KBStrategy::SHOT)
 	{
 		m_column = col;
 		m_row = row;
@@ -112,7 +113,7 @@ bool KBHorizontalStepStrategy::hasMoreShots()
 		// Child Strategy
 		if(m_passes == 0)
 		{
-			if(enemyFieldStateAt(m_column, m_row) != SHOT)
+			if(enemyFieldStateAt(m_column, m_row) != KBStrategy::SHOT)
 				return true;
 			else if(advance())
 				return true;
@@ -151,7 +152,7 @@ bool KBHorizontalStepStrategy::hasMoreShots()
 	switch(m_passes)
 	{
 		case 0:
-			if(enemyFieldStateAt(m_column, m_row) != SHOT || advance())
+			if(enemyFieldStateAt(m_column, m_row) != KBStrategy::SHOT || advance())
 				return true;
 
 			m_passes++;
