@@ -12,7 +12,10 @@ using namespace KGrid2D;
 FEBoard::FEBoard(bool graphic, QWidget *parent)
 : Board(graphic, new GiftPool(parent), parent),
   _field(matrix().width(), matrix().height()), _chainedPuyos(4), _nbPuyos(0)
-{}
+{
+  for (uint i=0; i<_chainedPuyos.count(); i++)
+    _chainedPuyos[i] = 0;
+}
 
 void FEBoard::copy(const GenericTetris &g)
 {
