@@ -16,15 +16,13 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 **************************************************************************** */
 #include <assert.h>
 #include <math.h>
 #include "cubebox.h"
-#include "cube.h"
 #include "kcubeboxwidget.h"
-#include "kcubewidget.h"
 
 
 CubeBox::CubeBox(const int d)
