@@ -32,7 +32,6 @@
 #include <qregexp.h>
 
 #include <klocale.h>
-#include <kkeydialog.h>
 #include <kfiledialog.h>
 #include <kmessagebox.h>
 #include <ktempfile.h>
@@ -41,13 +40,14 @@
 #include <kio/netaccess.h>
 #include <kstatusbar.h>
 
-#define ID_STATUS_TURN 1000
+#define ID_STATUS_TURN_TEXT 1000
+#define ID_STATUS_TURN      2000
 
 #define MESSAGE_TIME 2000
 
 
 KJumpingCube::KJumpingCube()
-	: view(new KCubeBoxWidget(5, this, "KCubeBoxWidget"))
+  : view(new KCubeBoxWidget(5, this, "KCubeBoxWidget"))
 {
    connect(view,SIGNAL(playerChanged(int)),SLOT(changePlayer(int)));
    connect(view,SIGNAL(stoppedMoving()),SLOT(disableStop()));
@@ -59,18 +59,20 @@ KJumpingCube::KJumpingCube()
    // tell the KMainWindow that this is indeed the main widget
    setCentralWidget(view);
 
-   initKAction();
-
-   QString s;
    // init statusbar
-   s = i18n("Current player: Player %1").arg(1);
-   statusBar()->insertItem(s+i18n("(Computer)"),ID_STATUS_TURN,2);
-   statusBar()->changeItem(s,ID_STATUS_TURN);
-   statusBar()->setItemAlignment (ID_STATUS_TURN,AlignLeft | AlignVCenter);
-   statusBar()->setFixedHeight( statusBar()->sizeHint().height());
+   QString s = i18n("Current player:");
+   statusBar()->insertItem(s,ID_STATUS_TURN_TEXT, false);
+   statusBar()->changeItem(s,ID_STATUS_TURN_TEXT);
+   statusBar()->setItemAlignment (ID_STATUS_TURN_TEXT, AlignLeft | AlignVCenter);
+   statusBar()->setFixedHeight( statusBar()->sizeHint().height() );
+ 
+   currentPlayer = new QWidget(this, "currentPlayer");
+   currentPlayer->setFixedWidth(40);
+   statusBar()->addWidget(currentPlayer, ID_STATUS_TURN, false);
+   statusBar()->setItemAlignment(ID_STATUS_TURN, AlignLeft | AlignVCenter);
 
-  resize(400,400);
-  setAutoSaveSettings();
+   initKAction();
+   changePlayer(1);
 }
 
 void KJumpingCube::initKAction() {
@@ -82,21 +84,13 @@ void KJumpingCube::initKAction() {
 
   hintAction = KStdGameAction::hint(view, SLOT(getHint()), actionCollection());
   stopAction = new KAction(i18n("Stop &Thinking"), "stop",
-	Qt::Key_Escape, this, SLOT(stop()), actionCollection(), "game_stop");
+  Qt::Key_Escape, this, SLOT(stop()), actionCollection(), "game_stop");
   stopAction->setEnabled(FALSE);
   undoAction = KStdGameAction::undo(this, SLOT(undo()), actionCollection());
   undoAction->setEnabled(FALSE);
-
-  createStandardStatusBarAction();
-  setStandardToolBarMenuEnabled(true);
-
-  KStdAction::keyBindings(this, SLOT(configureKeyBindings()),
-	actionCollection());
-
   KStdAction::preferences(this, SLOT(showOptions()), actionCollection());
 
-  // finally create toolbar and menubar
-  createGUI();
+  setupGUI();
 }
 
 void KJumpingCube::newGame(){
@@ -129,8 +123,8 @@ void KJumpingCube::saveGame(bool saveAs)
          if(KIO::NetAccess::exists(url,false,this))
          {
             QString mes=i18n("The file %1 exists.\n"
-			     "Do you want to overwrite it?").arg(url.url());
-	    result = KMessageBox::warningYesNoCancel(this, mes);
+               "Do you want to overwrite it?").arg(url.url());
+            result = KMessageBox::warningYesNoCancel(this, mes);
             if(result==KMessageBox::Cancel)
                return;
          }
@@ -172,7 +166,7 @@ void KJumpingCube::openGame()
       url = KFileDialog::getOpenURL( gameURL.url(), "*.kjc", this, 0 );
       if( url.isEmpty() )
          return;
-      if(!KIO::NetAccess::exists(url.url(),true,this))
+      if(!KIO::NetAccess::exists(url,true,this))
       {
          QString mes=i18n("The file %1 does not exist!").arg(url.url());
          KMessageBox::sorry(this,mes);
@@ -189,7 +183,7 @@ void KJumpingCube::openGame()
       if(!config.hasKey("Version"))
       {
          QString mes=i18n("The file %1 isn't a KJumpingCube gamefile!")
-		 .arg(url.url());
+           .arg(url.url());
          KMessageBox::sorry(this,mes);
          return;
       }
@@ -227,14 +221,9 @@ void KJumpingCube::undo()
 
 void KJumpingCube::changePlayer(int newPlayer)
 {
-   QString s=i18n("Current player: Player %1");
-   s=s.arg(newPlayer);
-   if(view->isComputer((KCubeBoxWidget::Player)newPlayer))
-      s+=i18n("(Computer)");
-
-   statusBar()->changeItem(s,ID_STATUS_TURN);
-
    undoAction->setEnabled(true);
+   currentPlayer->setBackgroundColor(newPlayer == 1 ? Prefs::color1() : Prefs::color2());
+   currentPlayer->repaint();
 }
 
 void KJumpingCube::showWinner(int player) {
@@ -272,10 +261,6 @@ void KJumpingCube::enableStop_Thinking(){
   statusBar()->message(i18n("Computing next move."));
 }
 
-void KJumpingCube::configureKeyBindings(){
-  KKeyDialog::configure(actionCollection(), this);
-}
-
 /**
  * Show Configure dialog.
  */
