@@ -17,14 +17,17 @@
  *                                                                         *
  ***************************************************************************/
 #include <kapplication.h>
-#include "ballpainter.moc"
+#include <kmessagebox.h>
 //#include "shotcounter.h"
 #include <qpainter.h>
 #include "linesboard.h"
 //#include <qcolor.h>
 #include <qjpegio.h>
 #include <kstandarddirs.h>
+#include <klocale.h>
+#include <stdlib.h>
 
+#include "prefs.h"
 
 #define PIXSIZE (CELLSIZE - 2)
 
@@ -36,18 +39,27 @@ int colorLinesArr[NCOLORS] =
 
 
 BallPainter::BallPainter()
-    : QObject()
+    : QObject(), backgroundPix(0)
 {
-    createPixmap();
+  createPix();
 }
 
 BallPainter::~BallPainter()
 {
-  delete backgroundPix;
-  delete imgCash;
-  delete firePix;
+  deletePix();
 }
-void BallPainter::createPixmap()
+
+void BallPainter::deletePix()
+{
+  delete backgroundPix;
+  for(int c=0; c<NCOLORS; c++)
+    for(int t=0; t<PIXTIME + FIREBALLS + BOOMBALLS + 1 ; t++)
+      delete imgCash[c][t];
+  for(int t=0; t < FIREPIX ; t++)
+    delete firePix[t];
+}
+
+void BallPainter::createPix()
 {
   backgroundPix = new QPixmap(
 		locate( "appdata", "field.jpg" ));
@@ -55,8 +67,11 @@ void BallPainter::createPixmap()
 		locate( "appdata", "balls.jpg" ));
   QPixmap *fire = new QPixmap(
 		locate( "appdata", "fire.jpg" ));
-  if (balls->isNull() ||backgroundPix->isNull() || fire->isNull() )
-     return; // Error
+  if (balls->isNull() ||backgroundPix->isNull() || fire->isNull() ) {
+      KMessageBox::error(0, i18n("Unable to find graphics. Check your installation."), i18n("Error"));
+      exit(1);
+      return; // Error
+  }
 
   for(int c=0; c<NCOLORS; c++)
   {
@@ -66,49 +81,62 @@ void BallPainter::createPixmap()
       QPainter p(imgCash[c][t]);
       p.drawPixmap(0,0,(*backgroundPix),0,0,CELLSIZE,CELLSIZE);
       p.drawPixmap(1,1,(*balls),t*PIXSIZE,c*PIXSIZE,PIXSIZE,PIXSIZE);
+      if (Prefs::numberedBalls() && (t == NORMALBALL))
+      {
+        if ((c == 2) || (c == 3) || (c == 6))
+          p.setPen(Qt::black);
+        else
+          p.setPen(Qt::white);
+        QString tmp;
+        tmp.setNum(c+1);
+        p.drawText(QRect(0,0,CELLSIZE,CELLSIZE), Qt::AlignCenter, tmp);
+      }
+      
     }
-    for(int t=0; t < FIREPIX ; t++)
-    {
-      firePix[t] = new QPixmap(CELLSIZE, CELLSIZE);
-      QPainter p(firePix[t]);
-      p.drawPixmap(0,0,(*backgroundPix),0,0,CELLSIZE,CELLSIZE);
-      p.drawPixmap(1,1,(*fire),t*PIXSIZE,0,PIXSIZE,PIXSIZE);
-    }
+  }
+  for(int t=0; t < FIREPIX ; t++)
+  {
+    firePix[t] = new QPixmap(CELLSIZE, CELLSIZE);
+    QPainter p(firePix[t]);
+    p.drawPixmap(0,0,(*backgroundPix),0,0,CELLSIZE,CELLSIZE);
+    p.drawPixmap(1,1,(*fire),t*PIXSIZE,0,PIXSIZE,PIXSIZE);
   }
   delete balls;
   delete fire;
 }
 
 
-QPixmap* BallPainter::GetBall(int color, int animstep, int panim)
+QPixmap BallPainter::GetBall(int color, int animstep, int panim)
 {
 //    return backgroundPix;
 
     if( (color<0) || (color>=NCOLORS) || (animstep<0) || color == NOBALL ){
-       return backgroundPix;
+       return *backgroundPix;
     }
     if ( panim == ANIM_JUMP )
     {
       if ( ( animstep < 0 ) || ( animstep >= PIXTIME ) )
-        return backgroundPix;
+        return *backgroundPix;
       else
-        return imgCash[color][animstep];
+        return *imgCash[color][animstep];
     }
     else if ( panim == ANIM_BURN )
     {
         if ( animstep < FIREBALLS )
-          return imgCash[color][animstep + PIXTIME + BOOMBALLS + 1];
+          return *imgCash[color][animstep + PIXTIME + BOOMBALLS + 1];
         else if ( animstep < FIREBALLS + FIREPIX )
-          return firePix[animstep - FIREBALLS];
+          return *firePix[animstep - FIREBALLS];
     }
     else if ( panim == ANIM_BORN )
     {
         if ( animstep < BOOMBALLS )
-          return imgCash[color][animstep + PIXTIME];
+          return *imgCash[color][animstep + PIXTIME];
         else
-          return imgCash[color][NORMALBALL];
+          return *imgCash[color][NORMALBALL];
     }
     // rest is not imlemented yet
-    return imgCash[color][NORMALBALL];
+    return *imgCash[color][NORMALBALL];
 
 }
+
+#include "ballpainter.moc"
