@@ -42,7 +42,6 @@
 #include <kaction.h>
 #include <kstdaction.h>
 #include <kstdgameaction.h>
-#include <kkeydialog.h>
 
 #include "cfg.h"
 #include "prefs.h"
@@ -73,15 +72,16 @@ KLines::KLines()
 
   lPrompt = mwidget->GetPrompt();
 
-  initKAction();
-
   score = 0;
   score_undo = 0;
+  bDemo = false;
 
   statusBar()->insertItem(i18n(" Score:"), 1, 1);
   statusBar()->setItemAlignment(1, AlignVCenter | AlignLeft);
   statusBar()->insertItem(i18n(" Level: "), 0, 1);
   statusBar()->setItemAlignment(0, AlignVCenter | AlignLeft);
+ 
+  initKAction();
 
   connect(&demoTimer, SIGNAL(timeout()), this, SLOT(slotDemo()));
 
@@ -100,25 +100,20 @@ KLines::~KLines()
   Prefs::writeConfig();
 }
 
-
-void KLines::slotConfigureKeys()
-{
-  KKeyDialog::configure( actionCollection(), this );
-}
-
 /*
    Init KAction objects (menubar, toolbar, shortcuts)
 */
 void KLines::initKAction()
 {
-  KStdAction::keyBindings( this, SLOT( slotConfigureKeys() ), actionCollection() );
   KStdGameAction::gameNew(this, SLOT(startGame()), actionCollection());
   act_demo = KStdGameAction::demo(this, SLOT(startDemo()), actionCollection());
+  act_demo->setText(i18n("Start &Tutorial"));
   KStdGameAction::highscores(this, SLOT(viewHighScore()), actionCollection());
   KStdGameAction::quit(this, SLOT(close()), actionCollection());
   endTurnAction = KStdGameAction::endTurn(this, SLOT(makeTurn()), actionCollection());
   showNextAction = new KToggleAction(i18n("&Show Next"), KShortcut(CTRL+Key_P),
                                 this, SLOT(switchPrompt()), actionCollection(), "options_show_next");
+  showNextAction->setCheckedState(i18n("Hide Next"));
   showNumberedAction = new KToggleAction(i18n("&Use Numbered Balls"), KShortcut(),
                                 this, SLOT(switchNumbered()), actionCollection(), "options_show_numbered");
   undoAction = KStdGameAction::undo(this, SLOT(undo()), actionCollection());
@@ -134,7 +129,13 @@ void KLines::initKAction()
   showNumberedAction->setChecked(Prefs::numberedBalls());
   lPrompt->setPrompt(Prefs::showNext());
 
-  createGUI();
+  (void)new KAction(i18n("Move Left"), Key_Left, lsb, SLOT(moveLeft()), actionCollection(), "left");
+  (void)new KAction(i18n("Move Right"), Key_Right, lsb, SLOT(moveRight()), actionCollection(), "right");
+  (void)new KAction(i18n("Move Up"), Key_Up, lsb, SLOT(moveUp()), actionCollection(), "up");
+  (void)new KAction(i18n("Move Down"), Key_Down, lsb, SLOT(moveDown()), actionCollection(), "down");
+  (void)new KAction(i18n("Move Ball"), Key_Space, lsb, SLOT(placePlayerBall()), actionCollection(), "place_ball");
+
+  setupGUI( KMainWindow::Save | Keys | StatusBar | Create );
 }
 
 void KLines::startGame()
@@ -143,10 +144,9 @@ void KLines::startGame()
     score_undo = 0;
     bUndo = true;
     bNewTurn = true;
-    if(bDemo) {
+    if(bDemo)
         stopDemo();
-        act_demo->setText(i18n("Start &Tutorial"));
-    }
+
     bFirst = true;
 
     int level = levelAction->currentItem()-2;
@@ -203,8 +203,7 @@ void KLines::stopDemo()
     bDemo = false;
     lsb->hideDemoText();
     demoTimer.stop();
-    levelStr = i18n("Tutorial - Stopped");
-    statusBar()->changeItem(i18n(" Level: %1").arg(levelStr), 0);
+    statusBar()->changeItem(i18n(" Level: %1").arg(i18n("Tutorial - Stopped")), 0);
     act_demo->setText(i18n("Start &Tutorial"));
 }
 
@@ -421,8 +420,7 @@ void KLines::focusOutEvent(QFocusEvent *ev)
    {
       lsb->hideDemoText();
       demoTimer.stop();
-      levelStr = i18n("Tutorial - Paused");
-      statusBar()->changeItem(i18n(" Level: %1").arg(levelStr), 0);
+      statusBar()->changeItem(i18n(" Level: %1").arg(i18n("Tutorial - Paused")), 0);
    }
    KMainWindow::focusOutEvent(ev);
 }
@@ -431,7 +429,6 @@ void KLines::focusInEvent(QFocusEvent *ev)
 {
    if (bDemo)
    {
-      levelStr = i18n("Tutorial");
       statusBar()->changeItem(i18n(" Level: %1").arg(levelStr), 0);
       slotDemo();
    }
@@ -494,8 +491,11 @@ void KLines::makeTurn()
     }
     if (lsb->gameOver())
        return;
-    if (!bDemo)
+    if (!bDemo){
        placeBalls();
+       if(sender() != lsb)
+         lsb->saveUndo();
+    }
     bNewTurn = true;
 }
 
