@@ -41,6 +41,8 @@ LinesBoard::LinesBoard( BallPainter * abPainter, QWidget* parent, const char* na
   demoLabel = 0;
   bGameOver = false;
   anim = ANIM_NO;
+  focusX = -1;
+  focusY = -1;
 //  waypos = 0;
 //  waylen = 0;
 //  jumpingRow = -1;
@@ -174,6 +176,12 @@ int LinesBoard::height() { return CELLSIZE * NUMCELLSH; }
 int LinesBoard::wHint() { return width(); }
 int LinesBoard::hHint() { return height(); }
 
+void LinesBoard::setGameOver(bool b)
+{
+  bGameOver = b;
+  focusX = -1;
+  focusY = -1;
+}
 
 
 void LinesBoard::paintEvent( QPaintEvent* )
@@ -222,6 +230,20 @@ void LinesBoard::paintEvent( QPaintEvent* )
        QString gameover_text = i18n("Game Over");
        p.drawText(0, 0, width(), height(), AlignCenter|Qt::WordBreak, gameover_text);
     }
+    else
+    {
+      if ((focusX >= 0) && (focusX < NUMCELLSW) &&
+          (focusY >= 0) && (focusY < NUMCELLSH))
+      {
+        QRect r;
+        r.setX(focusX*CELLSIZE+2);
+        r.setY(focusY*CELLSIZE+2);
+        r.setWidth(CELLSIZE-4);
+        r.setHeight(CELLSIZE-4);
+        paint->setPen(QPen(Qt::DotLine));
+        paint->drawRect(r);
+      }
+    }
     delete paint;
 }
 
@@ -236,6 +258,11 @@ void LinesBoard::mousePressEvent( QMouseEvent* e )
   int curRow = e->y() / CELLSIZE;
   int curCol = e->x() / CELLSIZE;
 
+  placePlayerBall(curCol, curRow);
+}
+
+void LinesBoard::placePlayerBall(int curCol, int curRow)
+{
   //check range
   if (!checkBounds( curCol, curRow ) )
     return;
@@ -263,6 +290,53 @@ void LinesBoard::mousePressEvent( QMouseEvent* e )
     AnimJump(curCol,curRow);
 }
 
+/*
+   Move focus thingy
+*/
+void LinesBoard::moveFocus(int dx, int dy)
+{
+  if (bGameOver) return;
+  if ((level == DEMO_LEVEL) && (!bAllowMove)) return;
+  if (focusX == -1)
+  {
+    focusX = 0;
+    focusY = 0;
+  }
+  else
+  {
+    focusX = (focusX + dx + NUMCELLSW) % NUMCELLSW;
+    focusY = (focusY + dy + NUMCELLSH) % NUMCELLSH;
+  }
+  repaint(FALSE);
+} 
+
+void LinesBoard::moveLeft()
+{
+  moveFocus(-1, 0);
+} 
+
+void LinesBoard::moveRight()
+{
+  moveFocus(1, 0);
+}
+
+void LinesBoard::moveUp()
+{
+  moveFocus(0, -1);
+}
+
+void LinesBoard::moveDown()
+{
+  moveFocus(0, 1);
+}
+
+void LinesBoard::placePlayerBall()
+{
+  if (bGameOver) return;
+  if ((level == DEMO_LEVEL) && (!bAllowMove)) return;
+  placePlayerBall(focusX, focusY);
+}
+
 void LinesBoard::AnimJump(int x, int y ) {
   if ( getBall(x,y) != NOBALL )
     if (!( anim == ANIM_JUMP &&  jumpingCol == x && jumpingRow == y ))
@@ -609,7 +683,7 @@ bool LinesBoard::existPath(int bx, int by, int ax, int ay)
     animmax = 0;
 //    waypos = 0;
     int x, y,dir;
-    for( x = bx, y = by,dir; (dir = pf[y][x]) != GO_A;x -=dx[dir],y -= dy[dir]) {
+    for( x = bx, y = by; (dir = pf[y][x]) != GO_A;x -=dx[dir],y -= dy[dir]) {
      	way[animmax].x = x;
      	way[animmax].y = y;
     	animmax++;
