@@ -1,19 +1,19 @@
 /*
- * Copyright (c) 1996-2002 Nicolas HADACEK (hadacek@kde.org)
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * Copyright (c) 1996-2003 Nicolas HADACEK (hadacek@kde.org)
  *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #ifndef DIALOGS_H
@@ -21,14 +21,14 @@
 
 #include <qpushbutton.h>
 
-#include "generic/ghighscores.h"
-#include "generic/gsettings.h"
-#include "generic/gmisc_ui.h"
+#include <kgamelcd.h>
+#include <kexthighscore.h>
 
 #include "defines.h"
-
+#include "settings.h"
 
 class KComboBox;
+class KIntNumInput;
 
 //-----------------------------------------------------------------------------
 class Smiley : public QPushButton, public KMines
@@ -56,7 +56,7 @@ class DigitalClock : public KGameLCDClock
 
     bool cheating() const { return _cheating; }
     uint nbActions() const { return _nbActions; }
-    KExtHighscores::Score score() const;
+    KExtHighscore::Score score() const;
 
  public slots:
     void start();
@@ -67,45 +67,55 @@ class DigitalClock : public KGameLCDClock
     void timeoutClock();
 
  private:
-    KExtHighscores::Score _first, _last;
+    KExtHighscore::Score _first, _last;
     uint _nbActions;
     bool _cheating, _customGame;
 };
 
 //-----------------------------------------------------------------------------
-class CustomConfig : public KConfigWidget, public KMines
+class CustomConfig : public QWidget, public KMines
 {
  Q_OBJECT
  public:
     CustomConfig();
 
-    static Level readLevel();
+    static const uint maxWidth;
+    static const uint minWidth;
+    static const uint maxHeight;
+    static const uint minHeight;
+
+    void init() { updateNbMines(); }
 
  private slots:
-    void updateNbMines();
     void typeChosen(int);
+    void updateNbMines();
 
  private:
     bool _block;
-    KConfigItem *_width, *_height, *_mines;
-    KComboBox   *_gameType;
+    KIntNumInput *_width, *_height, *_mines;
+    KComboBox    *_gameType;
 };
 
 //-----------------------------------------------------------------------------
-class GameConfig : public KConfigWidget, public KMines
+class GameConfig : public QWidget, public KMines
 {
  Q_OBJECT
  public:
     GameConfig();
 
+    static void saveLevel(Level::Type);
+
+    void init() { _magicDialogEnabled = true; }
+
  private slots:
-    void magicRevealToggled();
+    void magicModified(bool);
 
  private:
-    KConfigItem *_magic;
+    bool _magicDialogEnabled;
+
 };
 
-class AppearanceConfig : public KConfigWidget, public KMines
+class AppearanceConfig : public QWidget, public KMines
 {
  Q_OBJECT
  public:
