@@ -14,15 +14,15 @@
 
 using namespace std;
 
-static const char *description =
+static const char description[] =
 I18N_NOOP("KDE Minigolf Game");
 
-static const char *version = "1.1";
+static const char version[] = "1.1";
 
 static KCmdLineOptions options[] =
 {
 	{ "+file", I18N_NOOP("File"), 0 },
-	{ "course-info ", I18N_NOOP("Print course information and exit."), 0 },
+	{ "course-info ", I18N_NOOP("Print course information and exit"), 0 },
 	KCmdLineLastOption
 };
 
