@@ -8,6 +8,7 @@
 #include <qpushbutton.h>
 #include <qlineedit.h>
 #include <qvalidator.h>
+#include <qtextedit.h>
 
 #include <kapplication.h>
 #include <klocale.h>
@@ -40,11 +41,19 @@ GameBoard::GameBoard( QWidget *parent )
 
     neutralPlayer = Player::createNeutralPlayer();
     map = new Map;
+    
+    planets.setAutoDelete(true);
+    players.setAutoDelete(true);
 
     //********************************************************************
     // Create the widgets in the main window
     //********************************************************************
     mapWidget = new ConquestMap( map, this );
+    msgWidget = new QTextEdit( this );
+    msgWidget->setTextFormat(LogText);
+    msgWidget->setMinimumHeight(100);
+    msgWidget->setHScrollBarMode(QScrollView::AlwaysOff);
+    msgWidget->setPaper(QBrush(Qt::black));
     planetInfo = new PlanetInfo( this, palette );
     gameMessage = new QLabel( this );
     gameMessage->setPalette( palette );
@@ -70,7 +79,7 @@ GameBoard::GameBoard( QWidget *parent )
     splashScreen->setPixmap(QPixmap(IMAGE_SPLASH));
     splashScreen->setGeometry( 0, 0, 600, 550 );
 
-    setMinimumSize( 600, 550 );
+    setMinimumSize( 600, 600 );
 
     setMouseTracking( true );
     setFocusPolicy( StrongFocus );
@@ -94,6 +103,7 @@ GameBoard::GameBoard( QWidget *parent )
 
     layout2->addSpacing( 5 );
     layout2->addWidget( mapWidget, 0, AlignTop );
+    layout2->addWidget( msgWidget );
     layout2->addStretch( 1 );
 
     layout1->addSpacing( 5 );
@@ -126,10 +136,12 @@ GameBoard::~GameBoard()
     // Nothing much to do yet
 }
 
+#if 0
 QSize GameBoard::sizeHint() const
 {
     return QSize( 600, 550 );
 }
+#endif
 
 //************************************************************************
 // Keyboard Event handlers
@@ -175,16 +187,24 @@ GameBoard::keyPressEvent( QKeyEvent *e )
 
 }
 
+QString
+GameBoard::playerString(Player *player)
+{
+    if (!player)
+        player = currentPlayer->current();
+    return player->getColoredName();
+}
+
 //************************************************************************
 // Game engine/state machine
 //************************************************************************
 void
-GameBoard::turn( void )
+GameBoard::turn()
 {
     PlanetListIterator planetAi( planets );
     PlanetListIterator planetAttack( planets );
     Planet *target = 0;
-
+   
     switch( gameState ) {
     case NONE :
         // stuff for none
@@ -213,8 +233,8 @@ GameBoard::turn( void )
             endTurn->setEnabled( true );
             mapWidget->unselectPlanet();
 
-            gameMessage->setText( currentPlayer->current()->getName() +
-                                    i18n(": Select source planet...") );
+            gameMessage->setText( "<qt>" + playerString() + ": " +
+                                    i18n("Select source planet...") + "</qt>" );
             setFocus();
         }
 
@@ -231,8 +251,8 @@ GameBoard::turn( void )
             shipCountEdit->hide();
             endTurn->setEnabled( false );
             sourcePlanet->select();
-            gameMessage->setText( currentPlayer->current()->getName() +
-                                    i18n(": Select destination planet...") );
+            gameMessage->setText( "<qt>" + playerString() + ": " +
+                                    i18n("Select destination planet...") + "</qt>" );
             setFocus();
         }
 
@@ -322,13 +342,13 @@ GameBoard::turn( void )
 
          int ships;
          planetAi.toFirst();
-
+         
          while ((home = planetAi())) {
             if (home->getPlayer() == currentPlayer->current()) {
 
                            bool hasAttack = false;
                            ships = (int)floor(home->getFleet().getShipCount() * 0.7 );
-
+                           
                            if (ships >= 20) {
 
 				Planet *attack;
@@ -336,7 +356,7 @@ GameBoard::turn( void )
 			        planetAttack.toFirst();
 				while ((attack = planetAttack())) {
                                         bool skip = false;
-
+                                        
 					CoreLogic cl;
 					double dist = cl.distance( home, attack );
 
@@ -357,7 +377,7 @@ GameBoard::turn( void )
 					 	minDistance = dist;
 					}
 				}
-
+                           
                                 if (hasAttack) {
 			    		sendAttackFleet( home, target, ships );
                                 }
@@ -366,13 +386,13 @@ GameBoard::turn( void )
                                     minDistance = 100;
                                     int shipsToSend = 0;
                                     bool hasDestination = false;
-
+                                    
                                     while ((attack = planetAttack())) {
                                         bool skip = false;
                                         CoreLogic cl;
                                         double dist = cl.distance( home, attack );
                                         int homeships = (int)floor(home->getFleet().getShipCount() * 0.5 );
-
+                                        
                                         if ((dist < minDistance) &&  (attack->getPlayer() == currentPlayer->current()) &&
                                                         (attack->getFleet().getShipCount() < homeships )) {
                                                 AttackFleetListIterator FleetsinFlight( currentPlayer->current()->getAttackList() );
@@ -386,7 +406,7 @@ GameBoard::turn( void )
                                                 if (skip) continue;
 
                                                 shipsToSend = (int)floor((home->getFleet().getShipCount() - attack->getFleet().getShipCount()) / 2) ;
-
+                                                
 					  	target = attack;
 					   	hasDestination = true;
                                                 minDistance = dist;
@@ -400,12 +420,12 @@ GameBoard::turn( void )
     			  }
 		}
         }
-
+         
          endTurn->setEnabled( true );
          nextPlayer();
-
+         
     	break;
-
+     
     default:
         break;
     }
@@ -421,7 +441,7 @@ GameBoard::turn( void )
 // To the end turn processing (resolve combat, etc.)
 //************************************************************************
 void
-GameBoard::nextTurn( void )
+GameBoard::nextTurn()
 {
     resolveShipsInFlight();
 
@@ -435,41 +455,54 @@ GameBoard::nextTurn( void )
     // advance turn counter
     turnNumber++;
 
-    if( turnNumber == lastTurn ) {
-        // Last call
-        //KMsgBox::message( this, i18n("Last Turn"), i18n("This is the last turn."), KMsgBox::INFORMATION );
-
-        GameEndDlg *dlg = new GameEndDlg( this );
-
-        if( dlg->exec() ) {
-            lastTurn += dlg->addTurns;
-        }
-
-        delete dlg;
-    }
-
-    if( turnNumber > lastTurn ) {
-        // Game over, man! Game over.
-        cleanupGame();
-    };
-
     // update the planets
     PlanetListIterator nextPlanet( planets );
     Planet *planet;
 
-    while( (planet = nextPlanet()) ) {
+    while( (planet = nextPlanet()) )
+    {
         planet->turn();
     }
 
     // Tell the status widget to update itself
     planetInfo->rescanPlanets();
+
+    Player *winner = findWinner();
+    if (winner)
+    {
+        mapWidget->repaint(true);
+        KMessageBox::information(this, 
+              i18n("The mighty %1 has conquered the Galactic!").arg(winner->getName()),
+              i18n("Game Over"));
+    }
+
+    if( (turnNumber == lastTurn) && !winner )
+    {
+        mapWidget->repaint(true);
+        GameEndDlg *dlg = new GameEndDlg( this );
+
+        if( dlg->exec() == KDialogBase::Yes ) {
+            lastTurn += dlg->extraTurns();
+        }
+
+        delete dlg;
+    }
+
+    if( winner || (turnNumber >= lastTurn) )
+    {
+        // Game over, man! Game over.
+
+        mapWidget->repaint(true);
+
+        gameOver();
+    };
 }
 
 //************************************************************************
 // determine the fate of the ships in transit
 //************************************************************************
 void
-GameBoard::resolveShipsInFlight( void )
+GameBoard::resolveShipsInFlight()
 {
     AttackFleetList arrivingShips;
     PlayerListIterator nextPlayer( players );
@@ -493,11 +526,75 @@ GameBoard::resolveShipsInFlight( void )
 
 }
 
+Player *
+GameBoard::findWinner()
+{
+    Player *winner = 0;
+    int activePlayers = 0;
+
+    PlayerListIterator nextPlayer( players );
+    Player *plr;
+    
+    while( (plr = nextPlayer()) ) {
+        if (plr->isInPlay())
+        {
+            winner = plr;
+            activePlayers++;
+        }
+        else if (plr->getAttackList().count() != 0)
+        {
+            activePlayers++;
+        }
+    }
+    if (activePlayers == 1)
+        return winner;
+
+    return 0;
+}
+
+void
+GameBoard::gameMsg(const QString &msg, Player *player, Planet *planet, Player *planetPlayer)
+{
+    bool isHumanInvolved = false;
+       
+    QString color = "white";
+    QString colorMsg = msg;
+    QString plainMsg = msg;
+
+    if (player)
+    {
+       if (!player->isAiPlayer())
+          isHumanInvolved = true;
+       colorMsg = colorMsg.arg(playerString(player));
+       plainMsg = plainMsg.arg(player->getName());
+    }
+
+    if (planet)
+    {
+       if (!planetPlayer)
+          planetPlayer = planet->getPlayer();
+       if (!planetPlayer->isAiPlayer() && !planetPlayer->isNeutral())
+          isHumanInvolved = true;
+
+       QString color = planetPlayer->getColor().name();
+       colorMsg = colorMsg.arg(QString("<font color=\"%1\">%2</font>").arg(color, planet->getName()));
+       plainMsg = plainMsg.arg(planet->getName());
+    }
+    msgWidget->append(("<qt><font color=\"white\">Turn %1:</font> <font color=\""+color+"\">").arg(turnNumber)+colorMsg+"</font></qt>");
+    msgWidget->scrollToBottom();
+    
+    if (isHumanInvolved)
+    {
+       mapWidget->repaint(true);
+       KMessageBox::information(this, plainMsg);
+    }
+}
+
 //************************************************************************
 // check to see any players have been eliminated
 //************************************************************************
 void
-GameBoard::scanForSurvivors( void )
+GameBoard::scanForSurvivors()
 {
     PlayerListIterator nextPlayer( players );
     PlayerList activePlayers;
@@ -531,10 +628,8 @@ GameBoard::scanForSurvivors( void )
         if( !plr->isInPlay() ) {
             // Player has bitten the dust
             QString msg;
-            msg = i18n("The once mighty empire of %1 has fallen in ruins.")
-                  .arg(plr->getName());
-            KMessageBox::information( this, msg,
-				      i18n("An Empire Has Fallen") );
+            msg = i18n("The once mighty empire of %1 has fallen in ruins.");
+            gameMsg(msg, plr);
         }
     }
 
@@ -543,10 +638,8 @@ GameBoard::scanForSurvivors( void )
         if( plr->isInPlay() ) {
             // Player has bitten the dust
             QString msg;
-            msg = i18n("The fallen empire of %1 has staggered back to life.")
-		  .arg(plr->getName());
-	    KMessageBox::information( this, msg,
-				      i18n("Up From the Ashes") );
+            msg = i18n("The fallen empire of %1 has staggered back to life.");
+            gameMsg(msg, plr);
         }
     }
 }
@@ -567,9 +660,8 @@ GameBoard::doFleetArrival( AttackFleet *arrivingFleet )
 
         	QString msg;
         	msg = i18n("Reinforcements (%1 ships) have arrived for planet %2.")
-        	      .arg(arrivingFleet->getShipCount())
-        	      .arg(arrivingFleet->destination->getName());
-        	KMessageBox::information(this, msg, i18n("Fleet Arrival"));
+        	      .arg(arrivingFleet->getShipCount());
+                gameMsg(msg, 0, arrivingFleet->destination);
         }
     } else {
 
@@ -611,20 +703,17 @@ GameBoard::doFleetArrival( AttackFleet *arrivingFleet )
         if( planetHolds ) {
             prizePlanet.getPlayer()->statEnemyFleetsDestroyed(1);
             QString msg;
-            msg = i18n("Planet %1 has held against an attack from %2.")
-		  .arg(prizePlanet.getName())
-		  .arg(attacker.owner->getName());
-            KMessageBox::information(this, msg, i18n("Planet Holds"));
+            msg = i18n("Planet %2 has held against an attack from %1.");
+            gameMsg(msg, attacker.owner, &prizePlanet);
         } else {
+            Player *defender = prizePlanet.getPlayer();
             attacker.owner->statEnemyFleetsDestroyed( 1 );
 
             arrivingFleet->destination->conquer( arrivingFleet );
 
             QString msg;
-            msg = i18n("Planet %1 has fallen to %2.")
-                  .arg(prizePlanet.getName())
-		  .arg(attacker.owner->getName());
-            KMessageBox::information(this, msg, i18n("Planet Conquered"));
+            msg = i18n("Planet %2 has fallen to %1.");
+            gameMsg(msg, attacker.owner, &prizePlanet, defender);
         }
     }
 
@@ -644,12 +733,14 @@ GameBoard::startNewGame()
 
     NewGameDlg *newGame = new NewGameDlg( this, map, &players, neutralPlayer, &planets );
 
-
     if( !newGame->exec() )
     {
         delete newGame;
         return;
     }
+    newGame->save(); // Save settings for next time
+    
+    msgWidget->clear();
 
     changeGameBoard( true );
 
@@ -690,6 +781,12 @@ GameBoard::shutdownGame()
     if( choice == KMessageBox::Cancel )
         return;
 
+    gameOver();
+}
+
+void
+GameBoard::gameOver()
+{
     ScoreDlg *scoreDlg = new ScoreDlg( this, i18n("Final Standings"), &players );
     scoreDlg->exec();
 
@@ -697,21 +794,12 @@ GameBoard::shutdownGame()
 }
 
 void
-GameBoard::cleanupGame( void )
+GameBoard::cleanupGame()
 {
     map->clearMap();
 
-    Planet *planet;
-    planet = planets.first();
-    for( planet = planets.take(); planet != 0; planet = planets.take() ) {
-        delete planet;
-    }
-
-    Player *player;
-    player = players.first();
-    for( player = players.take(); player != 0; player = players.take() ) {
-        delete player;
-    }
+    planets.clear();
+    players.clear();
 
     delete currentPlayer;
     currentPlayer = NULL;
@@ -849,9 +937,9 @@ GameBoard::nextPlayer()
          }
          else {
              gameState = SOURCE_PLANET;
-
+        
         }
-       turn();
+       turn();   
     }
 }
 
