@@ -11,6 +11,8 @@
 #include <klocale.h>
 #include "cardmaps.h"
 #include "speeds.h"
+#include <kconfig.h>
+#include "version.h"
 
 DealerInfoList *DealerInfoList::_self = 0;
 static KStaticDeleter<DealerInfoList> dl;
@@ -32,7 +34,7 @@ Dealer *Dealer::s_instance = 0;
 Dealer::Dealer( KMainWindow* _parent , const char* _name )
     : QCanvasView( 0, _parent, _name ), towait(0), myActions(0),
 ademo(0), ahint(0), aredeal(0),
-      takeTargets(false), _won(false), _waiting(0), stop_demo_next(false), _autodrop(true)
+      takeTargets(false), _won(false), _waiting(0), stop_demo_next(false), _autodrop(true), moves(0)
 {
     setResizePolicy(QScrollView::Manual);
     setVScrollBarMode(AlwaysOff);
@@ -100,6 +102,8 @@ void Dealer::setupActions() {
 
 Dealer::~Dealer()
 {
+	 if (!_won)
+		 countLoss();
     clearHints();
     parent()->guiFactory()->unplugActionList( parent(), QString::fromLatin1("game_actions"));
 
@@ -441,6 +445,8 @@ void Dealer::contentsMouseReleaseEvent( QMouseEvent *e)
             }
         }
         c->source()->moveCards(movingCards, (*best).source);
+        ++moves;
+        emit setMoves( moves );
         takeState();
     }
     movingCards.clear();
@@ -541,6 +547,8 @@ bool Dealer::cardDblClicked(Card *c)
             CardList empty;
             empty.append(c);
             c->source()->moveCards(empty, tgt);
+            ++moves;
+            emit setMoves( moves );
             canvas()->update();
             return true;
         }
@@ -550,12 +558,15 @@ bool Dealer::cardDblClicked(Card *c)
 
 void Dealer::startNew()
 {
+    if (!_won)
+		 countLoss();
     if ( ahint )
         ahint->setEnabled( true );
     if ( ademo )
         ademo->setEnabled( true );
     if ( aredeal )
         aredeal->setEnabled( true );
+    toldAboutLostGame = false;
     minsize = QSize(0,0);
     _won = false;
     _waiting = 0;
@@ -586,6 +597,14 @@ void Dealer::startNew()
                 break;
         }
     }
+	 // count started game
+	 { // wrap in own scope to make KConfigGroupSave work
+    KConfig *config = kapp->config();
+    KConfigGroupSaver kcs(config, scores_group);
+	 unsigned int Total = config->readUnsignedNumEntry(QString("total%1").arg(_id),0);
+	 ++Total;
+	 config->writeEntry(QString("total%1").arg(_id),Total);
+	 }
     kdDebug(11111) << "startNew takeState\n";
     if (!towait)
         takeState();
@@ -758,14 +777,15 @@ void Dealer::takeState()
             won();
             return;
         }
-        else if (isGameLost()) {
-            QTimer::singleShot(400, this, SIGNAL(gameLost()));
+        else if (isGameLost() && !toldAboutLostGame) {
             if ( ahint )
                 ahint->setEnabled( false );
             if ( ademo )
                 ademo->setEnabled( false );
             if ( aredeal )
                 aredeal->setEnabled( false );
+            QTimer::singleShot(400, this, SIGNAL(gameLost()));
+            toldAboutLostGame = true;
             return;
         }
     }
@@ -783,6 +803,7 @@ void Dealer::saveGame(QDomDocument &doc) {
     QString data = getGameState();
     if (!data.isEmpty())
         dealer.setAttribute("data", data);
+    dealer.setAttribute("moves", QString::number(moves));
 
     bool taken[1000];
     memset(taken, 0, sizeof(taken));
@@ -794,7 +815,7 @@ void Dealer::saveGame(QDomDocument &doc) {
             Pile *p = dynamic_cast<Pile*>(*it);
             assert(p);
             if (taken[p->index()]) {
-                kdDebug() << "pile index " << p->index() << " taken twice\n";
+                kdDebug(11111) << "pile index " << p->index() << " taken twice\n";
                 return;
             }
             taken[p->index()] = true;
@@ -844,7 +865,7 @@ void Dealer::saveGame(QDomDocument &doc) {
     }
     dealer.appendChild(eList);
     */
-    // kdDebug() << doc.toString() << endl;
+    // kdDebug(11111) << doc.toString() << endl;
 }
 
 void Dealer::openGame(QDomDocument &doc)
@@ -890,7 +911,7 @@ void Dealer::openGame(QDomDocument &doc)
                         {
                             if ((*it2)->suit() == s && (*it2)->value() == v) {
                                 if (QString((*it2)->name()) == "Diamonds Eight") {
-                                    kdDebug() << i << " " << j << endl;
+                                    kdDebug(11111) << i << " " << j << endl;
                                 }
                                 p->add(*it2);
                                 (*it2)->setAnimated(false);
@@ -915,6 +936,9 @@ void Dealer::openGame(QDomDocument &doc)
         takeState(); // copying it again
         emit undoPossible(undoList.count() > 1);
     }
+    
+    emit setMoves( dealer.attribute("moves").toInt() );
+        
     takeState();
 }
 
@@ -925,6 +949,8 @@ void Dealer::undo()
     if (undoList.count() > 1) {
         undoList.removeLast(); // the current state
         setState(undoList.take(undoList.count() - 1));
+        --moves;
+        emit setMoves( moves );
         takeState(); // copying it again
         emit undoPossible(undoList.count() > 1);
     }
@@ -1080,6 +1106,19 @@ void Dealer::won()
     if (_won)
         return;
     _won = true;
+	 // update score, 'win' in demo mode also counts (keep it that way?)
+	 { // wrap in own scope to make KConfigGroupSave work
+    KConfig *config = kapp->config();
+    KConfigGroupSaver kcs(config, scores_group);
+	 unsigned int n = config->readUnsignedNumEntry(QString("won%1").arg(_id),0) + 1;
+	 config->writeEntry(QString("won%1").arg(_id),n);
+	 n = config->readUnsignedNumEntry(QString("winstreak%1").arg(_id),0) + 1;
+	 config->writeEntry(QString("winstreak%1").arg(_id),n);
+	 unsigned int m = config->readUnsignedNumEntry(QString("maxwinstreak%1").arg(_id),0);
+	 if (n>m)
+		 config->writeEntry(QString("maxwinstreak%1").arg(_id),n);
+	 config->writeEntry(QString("loosestreak%1").arg(_id),0);
+	 }
 
     // sort cards by increasing z
     QCanvasItemList list = canvas()->allItems();
@@ -1338,4 +1377,17 @@ MoveHint::MoveHint(Card * c, Pile *_to, bool d)
     _card = c; to = _to; _dropiftarget = d;
 }
 
+void Dealer::countLoss()
+{
+	 // update score
+    KConfig *config = kapp->config();
+    KConfigGroupSaver kcs(config, scores_group);
+	 unsigned int n = config->readUnsignedNumEntry(QString("loosestreak%1").arg(_id),0) + 1;
+	 config->writeEntry(QString("loosestreak%1").arg(_id),n);
+	 unsigned int m = config->readUnsignedNumEntry(QString("maxloosestreak%1").arg(_id),0);
+	 if (n>m)
+		 config->writeEntry(QString("maxloosestreak%1").arg(_id),n);
+	 config->writeEntry(QString("winstreak%1").arg(_id),0);
+}
+
 #include "dealer.moc"
