@@ -32,7 +32,7 @@
 #include <kdebug.h>
 #include "cardmaps.h"
 #include <kcarddialog.h>
-#include <klineeditdlg.h>
+#include <kinputdialog.h>
 #include <kstandarddirs.h>
 #include <kfiledialog.h>
 #include <ktempfile.h>
@@ -44,6 +44,7 @@
 #include <kmessagebox.h>
 #include <kaccelmanager.h>
 #include <kmenubar.h>
+#include "gamestatsimpl.h"
 
 static pWidget *current_pwidget = 0;
 
@@ -55,7 +56,6 @@ pWidget::pWidget()
     : KMainWindow(0, "pwidget"), dill(0)
 {
     current_pwidget = this;
-    setAutoSaveSettings();
     // KCrash::setEmergencySaveFunction(::saveGame);
     KStdAction::quit(kapp, SLOT(quit()), actionCollection(), "game_exit");
 
@@ -118,6 +118,8 @@ pWidget::pWidget()
     backs = new KAction(i18n("&Switch Cards..."), 0, this,
                         SLOT(changeBackside()),
                         actionCollection(), "backside");
+	 stats = new KAction(i18n("&Statistics"), 0, this, SLOT(showStats()),
+			 actionCollection(),"game_stats");
 
     animation = new KToggleAction(i18n( "&Animation on Startup" ),
                                   0, this, SLOT(animationChanged()),
@@ -125,12 +127,13 @@ pWidget::pWidget()
     dropaction = new KToggleAction(i18n("&Enable Autodrop"),
                                    0, this, SLOT(enableAutoDrop()),
                                    actionCollection(), "enable_autodrop");
+    dropaction->setCheckedState(i18n("Disable Autodrop"));
 
     KConfig *config = kapp->config();
     KConfigGroupSaver cs(config, settings_group );
 
     QString bgpath = config->readPathEntry("Background");
-    kdDebug() << "bgpath '" << bgpath << "'" << endl;
+    kdDebug(11111) << "bgpath '" << bgpath << "'" << endl;
     if (bgpath.isEmpty())
         bgpath = locate("wallpaper", "No-Ones-Laughing-3.jpg");
     background = QPixmap(bgpath);
@@ -146,10 +149,14 @@ pWidget::pWidget()
         game = max_type;
     games->setCurrentItem(game);
 
+    statusBar()->insertItem( "", 1, 0, true );
+
     createGUI(QString::null, false);
     KAcceleratorManager::manage(menuBar());
 
     newGameType();
+    adjustSize();
+    setAutoSaveSettings();
 }
 
 pWidget::~pWidget()
@@ -271,18 +278,35 @@ void pWidget::enableAutoDrop()
 
 void pWidget::newGame() {
     dill->setGameNumber(kapp->random());
+    setGameCaption();
     restart();
 }
 
 void pWidget::restart() {
     statusBar()->clear();
+    dill->resetMoves();
+    slotSetMoves( 0 );
     dill->startNew();
 }
 
+void pWidget::setGameCaption()
+{
+    QString name = games->currentText();
+    QString newname;
+    QString gamenum;
+    gamenum.setNum( dill->gameNumber() );
+    for (uint i = 0; i < name.length(); i++)
+        if (name.at(i) != QChar('&'))
+            newname += name.at(i);
+
+    setCaption( newname + " - " + gamenum );
+}
+
 void pWidget::newGameType()
 {
     delete dill;
     dill = 0;
+    slotSetMoves( 0 );
 
     uint id = games->currentItem();
     for (QValueList<DealerInfo*>::ConstIterator it = DealerInfoList::self()->games().begin(); it != DealerInfoList::self()->games().end(); ++it) {
@@ -295,6 +319,8 @@ void pWidget::newGameType()
             connect(dill, SIGNAL(saveGame()), SLOT(saveGame()));
             connect(dill, SIGNAL(gameInfo(const QString&)),
                     SLOT(slotGameInfo(const QString &)));
+            connect(dill, SIGNAL(setMoves(int)),
+                    SLOT(slotSetMoves(int)));
             dill->setGameId(id);
             dill->setupActions();
             dill->setBackgroundPixmap(background, midcolor);
@@ -317,13 +343,10 @@ void pWidget::newGameType()
         kdError() << "unimplemented game type " << id << endl;
         dill = DealerInfoList::self()->games().first()->createGame(this);
     }
-    QString name = games->currentText();
-    QString newname;
-    for (uint i = 0; i < name.length(); i++)
-        if (name.at(i) != QChar('&'))
-            newname += name.at(i);
 
-    setCaption( newname );
+    dill->resetMoves();
+
+    setGameCaption();
 
     KConfig *config = kapp->config();
     KConfigGroupSaver kcs(config, settings_group);
@@ -350,6 +373,11 @@ void pWidget::slotGameInfo(const QString &text)
     statusBar()->message(text, 3000);
 }
 
+void pWidget::slotSetMoves( int moves )
+{
+  statusBar()->changeItem( i18n("1 move", "%n moves", moves), 1 );
+}
+
 void pWidget::setBackSide(const QString &deck, const QString &cards)
 {
     KConfig *config = kapp->config();
@@ -377,16 +405,12 @@ void pWidget::setBackSide(const QString &deck, const QString &cards)
 
 void pWidget::chooseGame()
 {
-    KLineEditDlg dlg(i18n("Enter a game number (FreeCell deals are the same as in the FreeCell FAQ):"), QString::number(dill->gameNumber()), this);
-    dlg.setCaption(i18n("Game Number"));
-
     bool ok;
-    if (dlg.exec()) {
-        long number = dlg.text().toLong(&ok);
-        if (ok) {
-            dill->setGameNumber(number);
-            restart();
-        }
+    long number = KInputDialog::getText(i18n("Game Number"), i18n("Enter a game number (FreeCell deals are the same as in the FreeCell FAQ):"), QString::number(dill->gameNumber()), 0, this).toLong(&ok);
+    if (ok) {
+        dill->setGameNumber(number);
+        setGameCaption();
+        restart();
     }
 }
 
@@ -394,9 +418,9 @@ void pWidget::gameWon(bool withhelp)
 {
     QString congrats;
     if (withhelp)
-        congrats = i18n("Congratulations! We've won!");
+        congrats = i18n("Congratulations! We have won!");
     else
-        congrats = i18n("Congratulations! You've won!");
+        congrats = i18n("Congratulations! You have won!");
 #if TEST_SOLVER == 0
     KMessageBox::information(this, congrats, i18n("Congratulations!"));
 #endif
@@ -406,14 +430,39 @@ void pWidget::gameWon(bool withhelp)
 #endif
 }
 
+
 void pWidget::gameLost()
 {
-    if (KMessageBox::questionYesNo(this, i18n("You couldn't win this game, "
+    QString   dontAskAgainName = "gameLostDontAskAgain";
+
+    // The following code is taken out of kmessagebox.cpp in kdeui.
+    // Is there a better way?
+    KConfig  *config = 0;
+    QString grpNotifMsgs = QString::fromLatin1("Notification Messages");
+
+    config = KGlobal::config();
+    KConfigGroupSaver saver(config, grpNotifMsgs);
+    QString  dontAsk = config->readEntry(dontAskAgainName).lower();
+
+    // If we are ordered never to ask again and to continue the game,
+    // then do so.
+    if (dontAsk == "no")
+	return;
+    // If it says yes, we ask anyway. Just starting a new game would
+    // be incredibly annoying.
+    if (dontAsk == "yes")
+	dontAskAgainName = QString::null;
+
+    if (KMessageBox::questionYesNo(this, i18n("You could not win this game, "
                                               "but there is always a second try.\nStart a new game?"),
-                                   i18n("Couldn't Win!"),
-                                   i18n("New Game"), KStdGuiItem::cont()) == KMessageBox::Yes)
+                                   i18n("Could Not Win!"),
+                                   i18n("New Game"),
+				   KStdGuiItem::cont(),
+				   dontAskAgainName) == KMessageBox::Yes) {
         QTimer::singleShot(0, this, SLOT(newGame()));
- }
+    }
+}
+
 
 void pWidget::openGame(const KURL &url)
 {
@@ -441,6 +490,7 @@ void pWidget::openGame(const KURL &url)
             }
         }
         dill->openGame(doc);
+        setGameCaption();
         KIO::NetAccess::removeTempFile( tmpFile );
         recent->addURL(url);
         recent->saveEntries(KGlobal::config());
@@ -467,5 +517,13 @@ void pWidget::saveGame()
     recent->saveEntries(KGlobal::config());
 }
 
+void pWidget::showStats()
+{
+	GameStatsImpl* dlg = new GameStatsImpl(this,"statistics dialog");
+	if (dill)
+		dlg->showGameType(dill->gameId());
+	dlg->exec();
+}
+
 #include "pwidget.moc"
 
