@@ -19,13 +19,10 @@
  *
  */
 
-#include <stdio.h>
+#include "KSameWidget.h"
 
 #include <qwidget.h>
-#include <qpushbutton.h>
-#include <qpixmap.h>
 #include <qvbox.h>
-#include <qpopupmenu.h>
 
 #include <kapplication.h>
 #include <kiconloader.h>
@@ -35,41 +32,35 @@
 #include <knuminput.h>
 #include <klocale.h>
 #include <knotifyclient.h>
+#include <knotifydialog.h>
 #include <kfiledialog.h>
 #include <kmessagebox.h>
-#include <kmenubar.h>
 #include <kconfig.h>
-#include <kstdaction.h>
+#include <kstdgameaction.h>
 #include <kaction.h>
 #include <kdebug.h>
-#include <kkeydialog.h>
 
-#include "KSameWidget.h"
 #include "StoneWidget.h"
-#include "version.h"
 
 static int default_colors=3;
 
 #define Board 	KScoreDialog::Custom1
 
-KSameWidget::KSameWidget() : KMainWindow(0)
+KSameWidget::KSameWidget(QWidget *parent, const char* name, WFlags fl) :
+             KMainWindow(parent,name,fl)
 {
-        setCaption("");
-	KStdAction::openNew(this, SLOT(m_new()), actionCollection(), "game_new");
+	KStdGameAction::gameNew(this, SLOT(m_new()), actionCollection(), "game_new");
 	restart = new KAction(i18n("&Restart This Board"), CTRL+Key_R, this,
 						  SLOT(m_restart()), actionCollection(), "game_restart");
-       // KStdAction::open(this, SLOT(m_load()), actionCollection(), "game_load");
-       // KStdAction::save(this, SLOT(m_save()), actionCollection(), "game_save");
-	new KAction(i18n("S&how Highscore"), CTRL+Key_H, this,
-				SLOT(m_showhs()), actionCollection(), "game_highscores");
-	KStdAction::quit(this, SLOT(m_quit()), actionCollection(), "game_quit");
-        KStdAction::keyBindings( this, SLOT( slotConfigureKeys() ), actionCollection() );
-	undo = KStdAction::undo(this, SLOT(m_undo()),
-							actionCollection(), "edit_undo");
+	KStdGameAction::highscores(this, SLOT(m_showhs()), actionCollection(), "game_highscores");
+	KStdGameAction::quit(this, SLOT(close()), actionCollection(), "game_quit");
+	undo = KStdGameAction::undo(this, SLOT(m_undo()), actionCollection(), "edit_undo");
 
-	random = new KToggleAction(i18n("&Random Board"), 0, this,
-							   SLOT(m_tglboard()), actionCollection(),
-							   "random_board");
+	random = new KToggleAction(i18n("&Random Board"), 0, 0, 0, actionCollection(), "random_board");
+	showNumberRemaining = new KToggleAction(i18n("&Show Number Remaining"), 0, 0, 0, actionCollection(), "showNumberRemaining");
+
+	KStdAction::configureNotifications(this, SLOT(configureNotifications()),
+               actionCollection());
 
 	status=statusBar();
 	status->insertItem(i18n("Colors: XX"),1,1);
@@ -80,7 +71,6 @@ KSameWidget::KSameWidget() : KMainWindow(0)
 	stone = new StoneWidget(this,15,10);
 
 	connect( stone, SIGNAL(s_gameover()), this, SLOT(gameover()));
-
 	connect( stone, SIGNAL(s_colors(int)), this, SLOT(setColors(int)));
 	connect( stone, SIGNAL(s_board(int)), this, SLOT(setBoard(int)));
 	connect( stone, SIGNAL(s_marked(int)), this, SLOT(setMarked(int)));
@@ -92,32 +82,27 @@ KSameWidget::KSameWidget() : KMainWindow(0)
 	sizeChanged();
 	setCentralWidget(stone);
 
-	createGUI();
+	// Once the main view can scale then use defualt setupGUI() and remove the
+	//    noMerge="1" from the uirc file
+	// StatusBar | ToolBar
+	setupGUI(KMainWindow::Save | Keys | Create );
 
 	random->setChecked(true);
 	setScore(0);
 
-	if (!kapp->isRestored()) newGame(kapp->random(),default_colors);
-	kdDebug() << "test" << endl;
-}
-
-KSameWidget::~KSameWidget() {
-}
-
-void KSameWidget::slotConfigureKeys()
-{
-  KKeyDialog::configure( actionCollection(), this );
+	if (!kapp->isRestored())
+		newGame(kapp->random(),default_colors);
 }
 
 void KSameWidget::readProperties(KConfig *conf) {
-  Q_ASSERT(conf);
-  stone->readProperties(conf);
+	Q_ASSERT(conf);
+	stone->readProperties(conf);
 }
 
 void KSameWidget::saveProperties(KConfig *conf) {
-  Q_ASSERT(conf);
-  stone->saveProperties(conf);
-  conf->sync();
+	Q_ASSERT(conf);
+	stone->saveProperties(conf);
+	conf->sync();
 }
 
 void KSameWidget::sizeChanged() {
@@ -166,40 +151,19 @@ void KSameWidget::m_restart() {
 		newGame(stone->board(),default_colors);
 }
 
-void KSameWidget::m_load() {
-  kdDebug() << "menu load not supported" << endl;
-}
-
-void KSameWidget::m_save() {
-  kdDebug() << "menu save not supported" << endl;
-}
-
 void KSameWidget::m_undo() {
 	Q_ASSERT(stone);
 	stone->undo();
 }
 
-
 void KSameWidget::m_showhs() {
-  Q_ASSERT(stone);
-  stone->unmark();
-  KScoreDialog d(KScoreDialog::Name | KScoreDialog::Score, this);
-  d.addField(Board, i18n("Board"), "Board");
-  d.exec();
+	Q_ASSERT(stone);
+	stone->unmark();
+	KScoreDialog d(KScoreDialog::Name | KScoreDialog::Score, this);
+	d.addField(Board, i18n("Board"), "Board");
+	d.exec();
 }
 
-void KSameWidget::m_quit() {
-  Q_ASSERT(stone);
-  stone->unmark();
-  kapp->quit();
-  delete this;
-}
-
-void KSameWidget::m_tglboard() {
-	kdDebug() << "toggled" << endl;
-}
-
-
 void KSameWidget::setColors(int colors) {
 	status->changeItem(i18n("%1 Colors").arg(colors),1);
 }
@@ -209,22 +173,29 @@ void KSameWidget::setBoard(int board) {
 }
 
 void KSameWidget::setMarked(int m) {
-  status->changeItem(i18n("Marked: %1").arg(m, 6),3);
+	status->changeItem(i18n("Marked: %1").arg(m, 6),3);
+	m_markedStones=m;
 }
 
 void KSameWidget::stonesRemoved(int,int) {
-	KNotifyClient::event(winId(), "stones removed",
-	   i18n("%1 stones removed.").arg(stone->marked()));
+	KNotifyClient::event(winId(),"stones removed",
+	   i18n("One stone removed.","%n stones removed.",m_markedStones));
 }
 
 void KSameWidget::setScore(int score) {
-  status->changeItem(i18n("Score: %1").arg(score, 6),4);
-  undo->setEnabled(stone->undoPossible());
-  restart->setEnabled(!stone->isOriginalBoard());
+	if(showNumberRemaining->isChecked()){
+		QStringList list;
+		for(int i=1;i<=stone->colors();i++)
+			list.append(QString("%1").arg(stone->count(i)));
+		QString count = QString(" (%1)").arg(list.join(","));
+		status->changeItem(i18n("%1 Colors%2").arg(stone->colors()).arg(count),1);
+	}
+	status->changeItem(i18n("Score: %1").arg(score, 6),4);
+	undo->setEnabled(stone->undoPossible());
+	restart->setEnabled(!stone->isOriginalBoard());
 }
 
 void KSameWidget::gameover() {
-  kdDebug() << "GameOver" << endl;
   if (stone->hasBonus()) {
 	  KNotifyClient::event(winId(), "game won",
 		  i18n("You even removed the last stone, great job! "
@@ -245,4 +216,8 @@ void KSameWidget::gameover() {
     d.exec();
 }
 
+void KSameWidget::configureNotifications() {
+    KNotifyDialog::configure(this);
+}
+
 #include "KSameWidget.moc"
