@@ -72,7 +72,7 @@ class Board : public QWidget
 	Q_OBJECT
 
 public:
-	Board(QWidget *parent = 0);
+	Board(QWidget *parent = 0, const char *name=0);
 	~Board();
 
 	virtual void paintEvent(QPaintEvent *);
@@ -127,11 +127,15 @@ signals:
 
 public slots:
 	bool pause();
-
+  void loadSettings();
+	
 private slots:
 	void undrawConnection();
 	void gravity(int, bool);
 
+protected:
+	virtual QSize sizeHint() const;
+
 private: // functions
 	void initBoard();
 
