@@ -13,7 +13,7 @@ class KSField : public Field
 
  private slots:
     void removedLinesUpdated(uint i, uint removed);
-    void settingsChanged();
+    virtual void settingsChanged();
 };
 
 #endif
