@@ -28,7 +28,6 @@ this software.
 #include <kconfig.h>
 #include <kmenubar.h>
 #include <kstatusbar.h>
-#include <kkeydialog.h>
 
 #include "ksmiletris.h"
 #include "gamewindow.h"
@@ -46,10 +45,6 @@ const int default_height = 460;
 GameWindow::GameWindow(QWidget *, const char *name)
         : KMainWindow(0, name)
 {
-	setCaption(i18n("KSmileTris"));
-
-
-
         //New Games
         (void)KStdGameAction::gameNew(this,
                                   SLOT(menu_newGame()),
@@ -70,11 +65,6 @@ GameWindow::GameWindow(QWidget *, const char *name)
                                     SLOT(menu_highScores()),
                                     actionCollection());
 
-        //Configure Shortcuts
-        (void)KStdAction::keyBindings(this,
-                                    SLOT(menu_keyBindings()),
-                                    actionCollection());
-
         //Quit
         (void)KStdGameAction::quit(this,
                                SLOT(close()),
@@ -140,7 +130,7 @@ GameWindow::GameWindow(QWidget *, const char *name)
 	game->do_sounds = config->readBoolEntry("Sounds", true);
         ((KToggleAction*)actionCollection()->action("settings_sounds"))->setChecked(game->do_sounds);
 
-        createGUI("ksmiletrisui.rc");
+	setupGUI(KMainWindow::Save | Keys | StatusBar | Create);
 }
 
 void GameWindow::menu_newGame()
@@ -194,11 +184,6 @@ void GameWindow::menu_sounds()
 	config->writeEntry("Sounds", game->do_sounds);
 }
 
-void GameWindow::menu_keyBindings()
-{
-	KKeyDialog::configure(actionCollection(), this);
-}
-
 void GameWindow::updateStats(int level, int points)
 {
 	QString l, p;
