@@ -463,7 +463,7 @@ void KGameDialogMsgServerConfig::slotChangeAdmin()
  game()->electAdmin(newAdmin);
 }
 
-void KGameDialogMsgServerConfig::removeClient(Q_UINT32 id)
+void KGameDialogMsgServerConfig::removeClient(Q_UINT32 /*id*/)
 {
 //TODO
 }
@@ -484,7 +484,7 @@ void KGameDialogMsgServerConfig::setAdmin(bool a)
 	connect(d->changeMaxClients, SIGNAL(pressed()), this, SLOT(slotChangeMaxClients()));
 	d->changeAdmin = new QPushButton(i18n("Change Admin"), this);
 	connect(d->changeAdmin, SIGNAL(pressed()), this, SLOT(slotChangeAdmin()));
-	d->removeClient = new QPushButton(i18n("Remove Client With All Players"), this);
+	d->removeClient = new QPushButton(i18n("Remove Client with All Players"), this);
 	connect(d->removeClient, SIGNAL(pressed()), this, SLOT(slotRemoveClient()));
 	d->senderLayout->addWidget(d->changeMaxClients);
 	d->senderLayout->addWidget(d->changeAdmin);
