@@ -18,7 +18,7 @@
     Boston, MA 02111-1307, USA.
 */
 /*
-    $Id: kgame.h,v 1.58 2003/11/03 10:10:43 bhards Exp $
+    $Id: kgame.h,v 1.59 2004/03/26 12:51:18 raabe Exp $
 */
 #ifndef __KGAME_H_
 #define __KGAME_H_
@@ -752,7 +752,11 @@ protected:
     **/
     virtual void newPlayersJoin(KGamePlayerList *oldplayer,
 				KGamePlayerList *newplayer,
-				QValueList<int> &inactivate) {};
+				QValueList<int> &inactivate) {
+		Q_UNUSED( oldplayer );
+		Q_UNUSED( newplayer );
+		Q_UNUSED( inactivate );
+	};
 
     /**
     * Save the player list to a stream. Used for network game and load/save.
