@@ -29,21 +29,22 @@ class KMessageServer;
 class KMessageClientPrivate;
 
 /**
-  This class implements a client that can connect to a @ref KMessageServer object.
+  @short A client to connect to a KMessageServer
+
+  This class implements a client that can connect to a KMessageServer object.
   It can be used to exchange messages between clients.
 
-  Usually you will connect the signals @ref broadcastReceived and @ref forwardReceived to
+  Usually you will connect the signals broadcastReceived and forwardReceived to
   some specific slots. In these slot methods you can analyse the messages that are
   sent to you from other clients.
 
-  To send messages to other clients, use the methods @ref sendBroadcast (to send to all
-  clients) or @ref sendForward (to send to a list of selected clients).
+  To send messages to other clients, use the methods sendBroadcast() (to send to all
+  clients) or sendForward() (to send to a list of selected clients).
 
-  If you want to communicate with the @ref KMessageServer object directly (on a more low
-  level base), use the method @ref sendServerMessage to send a command to the server and
-  connect to the signal @ref serverMessageReceived to see all the incoming messages.
-  In that case the messages must be of the format specified in @ref KMessageServer.
-  @short A client to connect to a @ref KMessageServer
+  If you want to communicate with the KMessageServer object directly (on a more low
+  level base), use the method sendServerMessage to send a command to the server and
+  connect to the signal serverMessageReceived to see all the incoming messages.
+  In that case the messages must be of the format specified in KMessageServer.
   @author Burkhard Lehner <Burkhard.Lehner@gmx.de>
 */
 class KMessageClient : public QObject
@@ -54,8 +55,8 @@ public:
 
   /**
     Constructor.
-    Creates an unconnected KMessageClient object. Use @ref setServer later to connect to a
-    @ref KMessageServer object.
+    Creates an unconnected KMessageClient object. Use setServer() later to connect to a
+    KMessageServer object.
   */
   KMessageClient (QObject *parent = 0, const char *name = 0);
 
@@ -99,11 +100,11 @@ public:
   /**
     Connects the client to (another) server.
 
-    Tries to connect via a TCP/IP socket to a @ref KMessageServer object
+    Tries to connect via a TCP/IP socket to a KMessageServer object
     on the given host, listening on the specified port.
 
     If we were already connected, the old connection is closed.
-    @param The name of the host to connect to. Must be either a hostname which can 
+    @param host The name of the host to connect to. Must be either a hostname which can 
     be resolved to an IP or just an IP
     @param port The port to connect to
   */
@@ -112,11 +113,11 @@ public:
   /**
     Connects the client to (another) server.
 
-    Connects to the given server, using @ref KMessageDirect.
+    Connects to the given server, using KMessageDirect.
     (The server object has to be in the same process.)
 
     If we were already connected, the old connection is closed.
-    @param server The @ref KMessageServer to connect to
+    @param server The KMessageServer to connect to
   */
   void setServer (KMessageServer *server);
 
@@ -128,11 +129,11 @@ public:
   /**
     Connects the client to (another) server.
 
-    To use this method, you have to create a @ref KMessageIO object with new (indeed you must
-    create an instance of a subclass of @ref KMessageIO, e.g. @ref KMessageSocket or @ref KMessageDirect).
+    To use this method, you have to create a KMessageIO object with new (indeed you must
+    create an instance of a subclass of KMessageIO, e.g. KMessageSocket or KMessageDirect).
     This object must already be connected to the new server.
 
-    Calling this method disconnects any earlier connection, and uses the new @ref KMessageIO
+    Calling this method disconnects any earlier connection, and uses the new KMessageIO
     object instead. This object gets owned by the KMessageClient object, so don't delete
     or manipulate it afterwards.
 
@@ -144,34 +145,48 @@ public:
     our new ID.
 
     NOTE: The two other setServer methods are for convenience. If you use them, you don't
-    have to create a @ref KMessageIO object yourself.
+    have to create a KMessageIO object yourself.
   */
   virtual void setServer (KMessageIO *connection);
 
   /**
-    @return True, if a connection to a @ref KMessageServer has been started, and if the
-    connection is ready for transfering data. (It will return false e.g. as long as
+    @return True, if a connection to a KMessageServer has been started, and if the
+    connection is ready for transferring data. (It will return false e.g. as long as
     a socket connection hasn't been established, and it will also return false after
     a socket connection is broken.)
   */
   bool isConnected () const;
-  
-  /**
-    @return TRUE if @ref isConnected is true AND this is no local (like
-    @ref KMessageDirect) connection.
-  */
-  bool isNetwork () const; 
 
   /**
-    Sends a message to the @ref KMessageServer. If we are not yet connected to one, nothing
+    @return TRUE if isConnected() is true AND this is not a local (like
+    KMessageDirect) connection.
+  */
+  bool isNetwork () const;
+
+  /**
+    @return 0 if isConnected() is FALSE, otherwise the port number this client is
+    connected to. See also KMessageIO::peerPort and QSocket::peerPort.
+    @since 3.2
+  */
+  Q_UINT16 peerPort () const;
+
+  /**
+    @since 3.2
+    @return "localhost" if isConnected() is FALSE, otherwise the hostname this client is
+    connected to. See also KMessageIO::peerName() and QSocket::peerName().
+  */
+  QString peerName() const;
+
+  /**
+    Sends a message to the KMessageServer. If we are not yet connected to one, nothing
     happens.
 
     Use this method to send a low level command to the server. It has to be in the
-    format specified in @ref KMessageServer.
+    format specified in KMessageServer.
 
-    If you want to send messages to other clients, you will better use @ref sendBroadcast
-    and @ref sendForward.
-    @param msg The message to be sent to the server. Must be in the format specified in @ref KMessageServer.
+    If you want to send messages to other clients, you should use sendBroadcast()
+    and sendForward().
+    @param msg The message to be sent to the server. Must be in the format specified in KMessageServer.
   */
   void sendServerMessage (const QByteArray &msg);
 
@@ -180,8 +195,8 @@ public:
     The message consists of an arbitrary block of data with arbitrary length.
 
     All the clients will receive an exact copy of this block of data, which will be
-    processed in their @ref processBroadcast method.
-    @ref msg The message to be sent to the clients
+    processed in their processBroadcast() method.
+    @param msg The message to be sent to the clients
   */
   //AB: processBroadcast doesn't exist!! is processIncomingMessage meant?
   void sendBroadcast (const QByteArray &msg);
@@ -191,70 +206,70 @@ public:
     The message consists of an arbitrary block of data with arbitrary length.
 
     All clients will receive an exact copy of this block of data, which will be
-    processed in their @ref processForward method.
+    processed in their processForward() method.
 
     If the list contains client IDs that are not defined, they are ignored. If
     it contains an ID several times, that client will receive the message several
     times.
 
-    To send a message to the admin of the @ref KMessageServer, you can use 0 as clientID,
+    To send a message to the admin of the KMessageServer, you can use 0 as clientID,
     instead of using the real client ID.
-    @ref msg The message to be sent to the clients
-    @ref clients A list of clients the message shall be sent to
+    @param msg The message to be sent to the clients
+    @param clients A list of clients the message should be sent to
   */
   //AB: processForward doesn't exist!! is processIncomingMessage meant?
   void sendForward (const QByteArray &msg, const QValueList <Q_UINT32> &clients);
 
   /**
-    Sends a message to a single client. This is a convenicance method. It calls
-    sendForward (const QByteArray &msg, const QValueList <Q_UINT32> &clients)
+    Sends a message to a single client. This is a convenieance method. It calls
+    sendForward (const QByteArray &msg, const QValueList &ltQ_UINT32> &clients)
     with a list containing only one client ID.
 
-    To send a message to the admin of the @ref KMessageServer, you can use 0 as clientID,
+    To send a message to the admin of the  KMessageServer, you can use 0 as clientID,
     instead of using the real client ID.
-    @ref msg The message to be sent to the client
-    @ref clients The id of the client the message shall be sent to
+    @param msg The message to be sent to the client
+    @param client The id of the client the message shall be sent to
   */
   void sendForward (const QByteArray &msg, Q_UINT32 client);
 
   /**
-    Once this function is called no message will be received anymore. @ref 
-    processIncomingMessage gets delayed unti @ref unlock is called.
+    Once this function is called no message will be received anymore.
+    processIncomingMessage() gets delayed until unlock() is called.
 
-    Note that all messages are still received, but their delivery (like @ref 
-    broadcastReceived) get delayed only.
+    Note that all messages are still received, but their delivery (like
+    broadcastReceived()) get delayed only.
    */
   void lock();
 
   /**
-    Deliver every message that was delayed by @ref lock and actually deliver 
+    Deliver every message that was delayed by lock() and actually deliver 
     all messages that get received from now on.
    */
   void unlock();
 
   /**
-    @return The number of messages that got delayed since @ref lock was called
+    @return The number of messages that got delayed since lock() was called
    */
   unsigned int delayedMessageCount() const;
 
 signals:
   /**
     This signal is emitted when the client receives a broadcast message from the
-    @ref KMessageServer, sent by another client. Connect to this signal to analyse the
+    KMessageServer, sent by another client. Connect to this signal to analyse the
     received message and do the right reaction.
 
     senderID contains the ID of the client that sent the broadcast message. You can
     use this e.g. to send a reply message to only that client. Or you can use it
     to ignore broadcast messages that were sent by yourself:
 
-    <pre>
+    \code
       void myObject::myBroadcastSlot (const QByteArray &msg, Q_UINT32 senderID)
       {
         if (senderID == ((KMessageClient *)sender())->id())
           return;
         ...
       }
-    </pre>
+    \endcode
     @param msg The message that has been sent to us
     @param senderID The ID of the client which sent the message
   */
@@ -262,7 +277,7 @@ signals:
 
   /**
     This signal is emitted when the client receives a forward message from the
-    @ref KMessageServer, sent by another client. Connect to this signal to analyse the
+    KMessageServer, sent by another client. Connect to this signal to analyse the
     received message and do the right reaction.
 
     senderID contains the ID of the client that sent the broadcast message. You can
@@ -273,15 +288,15 @@ signals:
     sent to you.)
 
     If you don't want to distinguish between broadcast and forward messages and
-    treat them the same, you can connect @ref forwardReceived signal to the
-    @ref broadcastReceived signal. (Yes, that's possible! You can connect a Qt signal to
+    treat them the same, you can connect forwardReceived signal to the
+    broadcastReceived signal. (Yes, that's possible! You can connect a Qt signal to
     a Qt signal, and the second one can have less parameters.)
 
-    <pre>
+    \code
       KMessageClient *client = new KMessageClient ();
       connect (client, SIGNAL (forwardReceived (const QByteArray &, Q_UINT32, const QValueList <Q_UINT32>&)),
                client, SIGNAL (broadcastReceived (const QByteArray &, Q_UINT32)));
-    </pre>
+    \endcode
 
     Then connect the broadcast signal to your slot that analyzes the message.
     @param msg The message that has been sent to us
@@ -291,13 +306,13 @@ signals:
   void forwardReceived (const QByteArray &msg, Q_UINT32 senderID, const QValueList <Q_UINT32> &receivers);
 
   /**
-    This signal is emitted when the connection to the @ref KMessageServer is broken.
+    This signal is emitted when the connection to the KMessageServer is broken.
     Reasons for this can be: a network error, a server breakdown, or you were just kicked
     from the server.
 
     When this signal is sent, the connection is already lost and the client is unconnected.
-    You can connect to another server by calling @ref setServer afterwards. But keep in mind that
-    some important messages meight have vanished.
+    You can connect to another server by calling setServer() afterwards. But keep in mind that
+    some important messages might have vanished.
   */
   void connectionBroken ();
 
@@ -308,7 +323,7 @@ signals:
   void aboutToDisconnect(Q_UINT32 id);
 
   /**
-    This signal is emitted when this client becomes the admin client or when it looses
+    This signal is emitted when this client becomes the admin client or when it loses
     the admin client status. Connect to this signal if you have to do any initialization
     or cleanup.
     @param isAdmin Whether we are now admin or not
@@ -334,7 +349,7 @@ signals:
 
   /**
     This signal is emitted on every message that came from the server. You can connect to this
-    signal to see the messages directly. They are in the format specified in @ref KMessageServer.
+    signal to see the messages directly. They are in the format specified in KMessageServer.
 
     @param msg The message that has been sent to us
     @param unknown True when KMessageClient didn't recognize the message, i.e. it contained an unknown
@@ -349,15 +364,15 @@ signals:
 
 protected:
   /**
-    This slot is called from @ref processIncomingMessage or @ref 
+    This slot is called from processIncomingMessage or 
     processFirstMessage, depending on whether the client is locked or a delayed
-    message is still here (see @ref lock)
+    message is still here (see lock)
 
     It processes the message and analyses it. If it is a broadcast or a forward message from
-    another client, it emits the signal @ref processBroadcast or @ref processForward accordingly.
+    another client, it emits the signal processBroadcast or processForward accordingly.
 
     If you want to treat additional server messages, you can overwrite this method. Don't
-    forget to call @ref processIncomingMessage of your suberclass!
+    forget to call processIncomingMessage of your superclass!
 
     At the moment, the following server messages are interpreted:
 
@@ -369,14 +384,14 @@ protected:
 
 protected slots:
   /**
-    This slot is called from the signal @ref KMessageIO::received whenever a message from the
-    @ref KMessageServer arrives.
+    This slot is called from the signal KMessageIO::received whenever a message from the
+    KMessageServer arrives.
 
     It processes the message and analyses it. If it is a broadcast or a forward message from
-    another client, it emits the signal @ref processBroadcast or @ref processForward accordingly.
+    another client, it emits the signal processBroadcast or processForward accordingly.
 
     If you want to treat additional server messages, you can overwrite this method. Don't
-    forget to call @ref processIncomingMessage of your suberclass!
+    forget to call processIncomingMessage() of your superclass!
 
     At the moment, the following server messages are interpreted:
 
@@ -386,16 +401,16 @@ protected slots:
   virtual void processIncomingMessage (const QByteArray &msg);
 
   /**
-    Called from @ref unlock (using @ref QTimer::singleShot) until all delayed 
+    Called from unlock() (using QTimer::singleShot) until all delayed 
     messages are delivered.
   */
   void processFirstMessage();
 
   /**
-    This slot is called from the signal @ref KMessageIO::connectionBroken.
+    This slot is called from the signal KMessageIO::connectionBroken.
 
-    It deletes the internal @ref KMessageIO object, and resets the client to default
-    values. To connect again to another server, use @ref setServer.
+    It deletes the internal KMessageIO object, and resets the client to default
+    values. To connect again to another server, use setServer.
   */
   virtual void removeBrokenConnection ();
   void removeBrokenConnection2 ();
