@@ -26,19 +26,25 @@ class KToggleAction;
 class QObject;
 class KActionCollection;
 class KRecentFilesAction;
+class KSelectAction;
 
+
+//-----------------------------------------------------------------------------
 /**
- * @see KStdAction
+ * Replacement for KStdAction for KDE Games
  *
- * This class is an extension to the usual @ref KStdAction class which provides
+ * This class is an extension to the usual KStdAction class which provides
  * easy access to often used KDE actions
  *
  * Games often use different menu entries than other programs, e.g. games use
  * the menu "game" instead of "file". This class provides the entries which
- * differ from the usual @ref KStdAction entries.
+ * differ from the usual KStdAction entries.
+ *
+ * @see KStdAction
  *
  * @author Andreas Beckermann <b_mann@gmx.de>
  */
+// #### KDE4: transform in namespace
 class KStdGameAction
 {
 public:
@@ -49,24 +55,45 @@ public:
         // Game menu
         New=1, Load, LoadRecent, Save, SaveAs, End, Pause, Highscores,
         Print, Quit,
-	// Move menu
-	Repeat, Undo, Redo, Roll, EndTurn,
-	// Settings menu
-	Carddecks
+        // Move menu
+        Repeat, Undo, Redo, Roll, EndTurn,
+        // Settings menu
+        Carddecks,
+        ChooseGameType, // @since 3.2
+        ConfigureHighscores, // @since 3.2
+
+        Restart, // @since 3.2
+        Hint, // @since 3.2
+        Demo, // @since 3.2
+        Solve, // @since 3.2
+        ActionNone // @since 3.2
     };
 
-    /**
-     * Constructor.
-     **/
     KStdGameAction();
-    /**
-     * Destructor.
-     **/
     ~KStdGameAction();
 
+    /**
+     * Creates an action corresponding to the
+     * KStdAction::StdAction enum.
+     * @since 3.2
+     */
+    static KAction* create( StdGameAction id, const char *name,
+			    const QObject *recvr, const char *slot,
+			    KActionCollection* parent );
+
+    /**
+     * @since 3.2
+     */
+	static KAction* create( StdGameAction id,
+		const QObject *recvr, const char *slot,
+		KActionCollection* parent )
+		{ return create( id, 0, recvr, slot, parent ); }
+
+
     /**
      * Retrieve the action corresponding to the
-     * @ref KStdGameAction::StdGameAction enum.
+     * KStdGameAction::StdGameAction enum.
+     * @deprecated
      */
     static KAction *action(StdGameAction act_enum, const QObject *recvr = 0,
                            const char *slot = 0, KActionCollection *parent = 0,
@@ -74,10 +101,17 @@ public:
 
     /**
      * This will return the internal name of a given standard action.
+     * @since 3.2
+     */
+    static const char* name( StdGameAction id );
+
+    /**
+     * This will return the internal name of a given standard action.
+     * @deprecated
      */
     static const char* stdName(StdGameAction act_enum);
 
-    /** 
+    /**
      * Start a new game
      **/
     static KAction *gameNew(const QObject *recvr = 0, const char *slot = 0,
@@ -112,7 +146,7 @@ public:
      **/
     static KToggleAction *pause(const QObject *recvr = 0, const char *slot = 0,
                            KActionCollection *parent = 0, const char *name = 0L );
-    
+
     /**
      * Show the highscores.
      */
@@ -141,7 +175,7 @@ public:
                          KActionCollection *parent = 0, const char *name = 0L );
 
 
-   
+
     /**
      * Repeat the last move.
      **/
@@ -180,6 +214,48 @@ public:
     static KAction *carddecks(const QObject *recvr = 0, const char *slot = 0,
                                 KActionCollection *parent = 0, const char *name = 0L );
 
+    /**
+     * Display configure highscores dialog.
+     * @since 3.2
+     */
+    static KAction *configureHighscores(const QObject *recvr = 0, const char *slot = 0,
+                                KActionCollection *parent = 0, const char *name = 0L );
+
+    /**
+     * Give an advice/hint.
+     * @since 3.2
+     */
+    static KAction *hint(const QObject *recvr = 0, const char *slot = 0,
+                         KActionCollection *parent = 0, const char *name = 0L );
+
+    /**
+     * Show a demo.
+     * @since 3.2
+     */
+    static KToggleAction *demo(const QObject *recvr = 0, const char *slot = 0,
+                               KActionCollection *parent = 0, const char *name = 0L );
+
+    /**
+     * Solve the game.
+     * @since 3.2
+     */
+    static KAction *solve(const QObject *recvr = 0, const char *slot = 0,
+                          KActionCollection *parent = 0, const char *name = 0L );
+
+    /**
+     * Choose game type.
+     * @since 3.2
+     */
+    static KSelectAction *chooseGameType(const QObject *recvr = 0, const char *slot = 0,
+                                         KActionCollection *parent = 0, const char *name = 0L );
+
+    /**
+     * Restart game.
+     * @since 3.2
+     */
+    static KAction *restart(const QObject *recvr = 0, const char *slot = 0,
+                            KActionCollection *parent = 0, const char *name = 0L );
+
 };
 
 #endif
