@@ -10,7 +10,21 @@
 class SequenceArray;
 class BlockInfo;
 
-class BaseBoard : public QCanvasView, public GenericTetris
+//-----------------------------------------------------------------------------
+class FixedCanvasView : public QCanvasView
+{
+  Q_OBJECT
+public:
+  FixedCanvasView(QWidget *parent = 0, const char *name = 0);
+  
+  virtual QSize sizeHint() const;
+  
+public slots:
+  virtual void adjustSize();
+};
+
+//-----------------------------------------------------------------------------
+class BaseBoard : public FixedCanvasView, public GenericTetris
 {
  Q_OBJECT
  public:
@@ -40,12 +54,14 @@ class BaseBoard : public QCanvasView, public GenericTetris
     bool arcadeStageDone() const { return _arcadeStageDone; }
     virtual uint arcadeTodo() const { return 0; }
     virtual uint arcadeDone() const { return 0; }
-
+    
     virtual void settingsChanged();
-    uint blockSize() const;
     BlockInfo *next() const { return _next; }
 
     int firstColumnBlock(uint column) const;
+    
+ public slots:
+    virtual void adjustSize();
 
  protected slots:
     virtual bool timeout(); // return true if treated
@@ -54,7 +70,6 @@ class BaseBoard : public QCanvasView, public GenericTetris
     void updatePieceConfigSignal();
     void removedUpdated();
     void scoreUpdated();
-	void blockSizeChanged();
     void gameOverSignal();
 
  protected:
@@ -72,7 +87,6 @@ class BaseBoard : public QCanvasView, public GenericTetris
     virtual void gameOver();
     virtual void arcadePrepare() {}
 
-    bool animations() const { return _animations; }
     uint drawCode(const KGrid2D::Coord &) const;
     void computeNeighbours();
     void partialBlockFall(const KGrid2D::Coord &src, const KGrid2D::Coord &dest);
@@ -104,7 +118,7 @@ class BaseBoard : public QCanvasView, public GenericTetris
     uint           loop;
 
  private:
-    bool _animations, _arcade, _arcadeStageDone;
+    bool _arcade, _arcadeStageDone;
     uint _arcadeStage;
 
     void _afterRemove(bool first);
