@@ -4,14 +4,13 @@
 #include <qglobal.h>
 
 struct MainData {
-    const char *name, *trName, *description, *homepage, *removedLabel,
+    const char *appName, *trName, *description, *homepage, *removedLabel,
         *version, *longVersion;
 };
 
 struct BaseBoardInfo {
     uint width, height;
     bool withPieces;
-    bool blockSizeMustBeOdd;
 
     uint beforeRemoveTime, afterRemoveTime;
     uint nbToggles, nbFallStages;
@@ -21,9 +20,6 @@ struct BaseBoardInfo {
     const uint *histogram;
     uint histogramSize;
     bool scoreBound;
-
-    // settings defaults
-    uint minBlockSize, maxBlockSize, defaultBlockSize;
 };
 
 class BaseBoard;
@@ -51,10 +47,12 @@ class BaseFactory
     virtual QWidget *createAppearanceConfig();
     virtual QWidget *createColorConfig();
     virtual QWidget *createGameConfig() { return 0; }
+ 
+ protected:
+    KAboutData *_aboutData;
 
  private:
     static BaseFactory *_self;
-    KAboutData         *_aboutData;
 };
 
 #endif
