@@ -1,15 +1,14 @@
 #ifndef BASE_MAIN_H
 #define BASE_MAIN_H
 
-#include <kmainwindow.h>
-
+#include "kzoommainwindow.h"
 
 class BaseInterface;
 class KToggleAction;
 class KKeyDialog;
 class KConfigDialog;
 
-class BaseMainWindow : public KMainWindow
+class BaseMainWindow : public KZoomMainWindow
 {
     Q_OBJECT
 public:
@@ -20,7 +19,6 @@ signals:
     void settingsChanged();
 
 private slots:
-    void toggleMenubar();
     void start();
     void pause();
     void showHighscores();
@@ -32,16 +30,18 @@ private slots:
 protected:
     BaseInterface     *_inter;
 
-    bool eventFilter(QObject *, QEvent *);
-    bool queryExit();
-    void readSettings();
-    void buildGUI(QWidget *);
+    void buildGUI(QWidget *widget);
     virtual void addConfig(KConfigDialog *) {}
     virtual void addKeys(KKeyDialog &) {}
     virtual void saveKeys() {}
+    
+    virtual void writeZoomSetting(uint zoom);
+    virtual uint readZoomSetting() const;
+    virtual void writeMenubarVisibleSetting(bool visible);
+    virtual bool menubarVisibleSetting() const;
 
 private:
-    KToggleAction *_menu, *_pause;
+    KToggleAction *_pause;
 };
 
 #endif
