@@ -27,8 +27,9 @@ class CommonFactory : public BaseFactory
     virtual BaseField *createField(QWidget *parent) = 0;
     virtual AI *createAI() = 0;
 
-    KConfigWidget *createAIConfig();
-    KConfigWidget *createGameConfig();
+    QWidget *createAIConfig();
+    virtual QWidget *createAppearanceConfig();
+    virtual QWidget *createGameConfig();
 };
 
 #endif
