@@ -6,13 +6,13 @@
 
 class MainWindow : public BaseMainWindow
 {
- Q_OBJECT
- public:
+    Q_OBJECT
+public:
     MainWindow() {}
 
- protected:
+protected:
     void init();
-    void addConfigWidgets(KConfigDialog &);
+    void addConfig(KConfigDialog *);
     void addKeys(KKeyDialog &);
     void saveKeys();
 };
