@@ -28,8 +28,6 @@
 #include <kstdaction.h>
 #include <kaction.h>
 #include <kdebug.h>
-#include <kkeydialog.h>
-
 
 // application specific includes
 #include "lskat.h"
@@ -37,19 +35,15 @@
 #include "lskatdoc.h"
 #include "namedlg.h"
 #include "networkdlg.h"
-#include "aboutdlg.h"
-#include "movielabel.h"
 #include "msgdlg.h"
 #include <kcarddialog.h>
 
-
 #include <stdlib.h>
 #include <kstatusbar.h>
 
 #define ACTION(x)   (actionCollection()->action(x))
 #define ID_STATUS_MSG               1003
 #define ID_STATUS_MOVER              1002
-#define ID_STATUS_TIME               1001
 
 LSkatApp::LSkatApp() : KMainWindow(0)
 {
@@ -67,15 +61,15 @@ LSkatApp::LSkatApp() : KMainWindow(0)
   // call inits to invoke all other construction parts
   initGUI();
   initStatusBar();
-  setHelpMenuEnabled(false);
+  
+  setupGUI(KMainWindow::StatusBar | Save);
   createGUI(QString::null, false);
 
   initDocument();
   initView();
 
-  readOptions();
+  doc->ReadConfig(config);
 
-  
   // Needs to be after readOptions as we read in default paths
   doc->LoadGrafix(mGrafix);
 
@@ -96,7 +90,6 @@ LSkatApp::LSkatApp() : KMainWindow(0)
 
   // better be last in init
   checkMenus();
-
 }
 
 LSkatApp::~LSkatApp()
@@ -123,14 +116,8 @@ void LSkatApp::checkMenus(int menu)
     {
       disableAction("send_message");
     }
-
   }
-  if (!menu || (menu&CheckViewMenu))
-  {
-    if (statusBar()->isHidden()) ((KToggleAction*)ACTION("show_statusbar"))->setChecked(false);
-    else ((KToggleAction*)ACTION("show_statusbar"))->setChecked(true);
-  }
-
+  
   if (!menu || (menu&CheckOptionsMenu))
   {
     ((KSelectAction *)ACTION("startplayer"))->setCurrentItem(doc->GetStartPlayer());
@@ -170,7 +157,7 @@ void LSkatApp::checkMenus(int menu)
 void LSkatApp::initGUI()
 {
   QStringList list;
-  
+
   (void)KStdAction::openNew(this, SLOT(slotFileNew()), actionCollection(), "new_game");
   ACTION("new_game")->setStatusText(i18n("Starting a new game..."));
   ACTION("new_game")->setWhatsThis(i18n("Starting a new game..."));
@@ -190,11 +177,6 @@ void LSkatApp::initGUI()
   ACTION("game_exit")->setStatusText(i18n("Exiting..."));
   ACTION("game_exit")->setWhatsThis(i18n("Quits the program."));
 
-  (void)new KToggleAction(i18n("&Show Statusbar"),0,this,SLOT(slotViewStatusBar()),
-                      actionCollection(), "show_statusbar");
-  ACTION("show_statusbar")->setStatusText(i18n("Toggle the statusbar..."));
-  ACTION("show_statusbar")->setWhatsThis(i18n("Toggle the statusbar..."));
-
   (void)new KSelectAction(i18n("Starting Player"),0,this,SLOT(slotStartplayer()),
                       actionCollection(), "startplayer");
   ACTION("startplayer")->setStatusText(i18n("Changing starting player..."));
@@ -228,7 +210,7 @@ void LSkatApp::initGUI()
   list.append(i18n("&Advanced"));
   list.append(i18n("&Hard"));
   ((KSelectAction *)ACTION("choose_level"))->setItems(list);
- 
+
   (void)new KAction(i18n("Select &Card Deck..."), 0, this, SLOT(slotOptionsCardDeck()),
                       actionCollection(), "select_carddeck");
   ACTION("select_carddeck")->setStatusText(i18n("Configure card decks..."));
@@ -243,12 +225,8 @@ void LSkatApp::initGUI()
   connect(actionCollection(), SIGNAL(actionStatusText(const QString &)), SLOT(slotStatusMsg(const QString &)));
   connect(actionCollection(), SIGNAL(clearStatusText()), SLOT(slotClearStatusMsg()));
 
-  KStdAction::keyBindings(this, SLOT(slotKeyBindings()), actionCollection());
-
-  KHelpMenu *helpMenu = new KHelpMenu(this, 0, true, actionCollection());
-  connect( helpMenu, SIGNAL(showAboutApplication()), this, SLOT(slotHelpAbout()));
-
-  
+  KStdAction::keyBindings(guiFactory(), SLOT(configureShortcuts()), 
+actionCollection());
 }
 
 
@@ -258,17 +236,11 @@ void LSkatApp::initStatusBar()
   // STATUSBAR
   // statusBar()->setInsertOrder(KStatusBar::RightToLeft);
   statusBar()->insertItem(i18n("This leaves space for the mover"),ID_STATUS_MOVER,0,true);
-  statusBar()->insertItem(i18n("23:45"),ID_STATUS_TIME,0,true);
   statusBar()->insertItem(i18n("Ready"), ID_STATUS_MSG);
 
-  slotStatusTime();
   slotStatusMover(i18n("(c) Martin Heni   "));
   slotStatusMsg(i18n("Welcome to Lieutenant Skat"));
 
-  // status bar clock
-  statusTimer=new QTimer(this);
-  connect(statusTimer,SIGNAL(timeout()),this,SLOT(slotStatusTimer()));
-  statusTimer->start(10000,false);
   // computer move timer
   procTimer=new QTimer(this);
   connect(procTimer,SIGNAL(timeout()),this,SLOT(slotProcTimer()));
@@ -299,7 +271,7 @@ void LSkatApp::enableAction(const char *s)
     KAction *act=actionCollection()->action(s);
     if (act) act->setEnabled(true);
   }
-    
+
 }
 void LSkatApp::disableAction(const char *s)
 {
@@ -315,30 +287,6 @@ LSkatDoc *LSkatApp::getDocument() const
   return doc;
 }
 
-void LSkatApp::saveOptions()
-{
-  config->setGroup("General Options");
-  config->writeEntry("Geometry", size());
-  config->writeEntry("Show Statusbar",statusBar()->isVisible());
-  doc->WriteConfig(config);
-}
-
-
-void LSkatApp::readOptions()
-{
-  config->setGroup("General Options");
-  bool bViewStatusbar = config->readBoolEntry("Show Statusbar", true);
-  ((KToggleAction *)ACTION("show_statusbar"))->setChecked(bViewStatusbar);
-  if(!bViewStatusbar) statusBar()->hide();
-
-  QSize size=config->readSizeEntry("Geometry");
-  if(!size.isEmpty())
-  {
-    resize(size);
-  }
-  doc->ReadConfig(config);
-}
-
 void LSkatApp::saveProperties(KConfig *_cfg)
 {
   if(doc->getTitle()!=i18n("Untitled") && !doc->isModified())
@@ -396,7 +344,7 @@ bool LSkatApp::queryClose()
 
 bool LSkatApp::queryExit()
 {
-  saveOptions();
+  doc->WriteConfig(config);
   return true;
 }
 
@@ -404,11 +352,9 @@ bool LSkatApp::queryExit()
 // SLOT IMPLEMENTATION
 /////////////////////////////////////////////////////////////////////
 
-
 void LSkatApp::slotFileStatistics()
 {
    QString message;
-
    message=i18n("Do you really want to clear the all time "
                 "statistical data?");
 
@@ -418,6 +364,7 @@ void LSkatApp::slotFileStatistics()
     doc->slotUpdateAllViews(0);
   }
 }
+
 /** send message */
 void LSkatApp::slotFileMessage()
 {
@@ -443,8 +390,6 @@ void LSkatApp::slotFileMessage()
   }
 }
 
-
-
 void LSkatApp::slotFileNew()
 {
   NewGame();
@@ -475,27 +420,26 @@ void LSkatApp::slotFileEnd()
   slotStatusNames();
 }
 
-
 void LSkatApp::slotFileQuit()
 {
-  saveOptions();
+  doc->WriteConfig(config);
   if (view) view->close();
   close();
   kdDebug() << "slotFileQuit done"<<endl;
 }
 
-
 void LSkatApp::slotStartplayer()
 {
   int i=((KSelectAction *)ACTION("startplayer"))->currentItem();
   doc->SetStartPlayer(i);
   doc->UpdateViews(UPDATE_STATUS);
 }
+
 void LSkatApp::slotPlayer1By()
 {
   switch(((KSelectAction *)ACTION("player1"))->currentItem())
   {
-    case 0: 
+    case 0:
         slotPlayer1(KG_INPUTTYPE_INTERACTIVE);
     break;
     case 1:
@@ -506,11 +450,12 @@ void LSkatApp::slotPlayer1By()
     break;
   }
 }
+
 void LSkatApp::slotPlayer2By()
 {
   switch(((KSelectAction *)ACTION("player2"))->currentItem())
   {
-    case 0: 
+    case 0:
         slotPlayer2(KG_INPUTTYPE_INTERACTIVE);
     break;
     case 1:
@@ -521,6 +466,7 @@ void LSkatApp::slotPlayer2By()
     break;
   }
 }
+
 void LSkatApp::slotPlayer1(KG_INPUTTYPE i)
 {
   doc->SetPlayedBy(0,i);
@@ -537,6 +483,7 @@ void LSkatApp::slotPlayer1(KG_INPUTTYPE i)
   }
   doc->UpdateViews(UPDATE_STATUS);
 }
+
 void LSkatApp::slotPlayer2(KG_INPUTTYPE i)
 {
   doc->SetPlayedBy(1,i);
@@ -553,6 +500,7 @@ void LSkatApp::slotPlayer2(KG_INPUTTYPE i)
   }
   doc->UpdateViews(UPDATE_STATUS);
 }
+
 void LSkatApp::slotOptionsNames()
 {
   NameDlg *dlg=new NameDlg(this,QCString("Enter your name..."));
@@ -581,7 +529,6 @@ void LSkatApp::slotOptionsCardDeck()
     doc->SetCardDeckPath(s1,s2);
     doc->slotUpdateAllViews(0);
   }
-
 }
 
 void LSkatApp::slotLevel()
@@ -593,23 +540,11 @@ void LSkatApp::slotLevel()
   printf("Level set to %d\n",i);
 }
 
-void LSkatApp::slotViewStatusBar()
-{
-  ///////////////////////////////////////////////////////////////////
-  //turn Statusbar on or off
-  if (statusBar()->isVisible()) 
-  {
-    statusBar()->hide();
-  }
-  else
-  {
-    statusBar()->show();
-  }
-}
 void LSkatApp::slotClearStatusMsg()
 {
   slotStatusMsg(i18n("Ready"));
 }
+
 void LSkatApp::slotStatusMsg(const QString &text)
 {
   ///////////////////////////////////////////////////////////////////
@@ -626,21 +561,6 @@ void LSkatApp::slotStatusMover(const QString &text)
   statusBar()->changeItem(text, ID_STATUS_MOVER);
 }
 
-void LSkatApp::slotStatusTime()
-{
-  ///////////////////////////////////////////////////////////////////
-  // change status time permanently
-  QString s;
-  QTime now;
-
-  now=QTime::currentTime();
-  s=now.toString();
-  s.truncate(5);
-
-  statusBar()->clear();
-  statusBar()->changeItem(s, ID_STATUS_TIME);
-}
-
 
 void LSkatApp::slotStatusHelpMsg(const QString &text)
 {
@@ -649,7 +569,6 @@ void LSkatApp::slotStatusHelpMsg(const QString &text)
   statusBar()->message(text, 2000);
 }
 
-
 /** Triggers the processmove timer */
 void LSkatApp::slotProcTimer(void)
 {
@@ -661,10 +580,6 @@ void LSkatApp::slotProcTimer(void)
   */
 }
 
-/** Triggers the status timer */
-void LSkatApp::slotStatusTimer(void){
-  slotStatusTime();
-}
 /** Set the names in the mover field */
 void LSkatApp::slotStatusNames(){
 
@@ -829,22 +744,6 @@ bool LSkatApp::MakeInputDevice(int no)
   return res;
 }
 
-void LSkatApp::slotHelpAbout()
-{
-  slotStatusMsg(i18n("About the program..."));
-
-  EMovie *movie=new EMovie;
-  movie->frameDelay=70;
-  movie->frameArray=doc->mPixAnim;
-  movie->frameCnt=NO_OF_ANIM;
-  aboutDlg *dlg=new aboutDlg(this);
-  dlg->SetMovie(movie);
-  dlg->exec();
-  delete movie;
-  slotStatusMsg(i18n("Ready"));
-}
-
-
 void LSkatApp::OptionsNetwork()
 {
   int res;
@@ -873,18 +772,21 @@ void LSkatApp::slotPrepareProcessMove(KEMessage *msg)
     msg->AddData(QCString("KLogSendMsg"),"process.log");
   PrepareGame(msg);
 }
+
 void LSkatApp::slotPrepareRemoteMove(KEMessage *)
 {
   if (global_debug>3)
     printf("+++ main should prepare remote move\n");
   slotStatusMsg(i18n("Waiting for remote player..."));
 }
+
 void LSkatApp::slotPrepareInteractiveMove(KEMessage *)
 {
   if (global_debug>3)
     printf("+++ main should prepare interactive move\n");
   slotStatusMsg(i18n("Please make your move..."));
 }
+
 void LSkatApp::slotReceiveInput(KEMessage *msg,int )
 {
   /*
@@ -1041,6 +943,7 @@ void LSkatApp::MoveFinished()
     }
     slotStatusNames();
 }
+
 void LSkatApp::Move(int x,int y,int player,bool remote)
 {
   KEMessage *msg;
@@ -1090,9 +993,12 @@ void LSkatApp::Move(int x,int y,int player,bool remote)
     return ;
   }
 }
+
 void LSkatApp::PrepareGame(KEMessage *msg)
 {
-  if (!msg) return ;
+  if (!msg)
+    return;
+
   msg->AddData(QCString("Cards"),(char *)doc->GetCardP(),NO_OF_CARDS*sizeof(int));
   msg->AddData(QCString("Startplayer"),(short)doc->GetStartPlayer());
   msg->AddData(QCString("CurrentPlayer"),(short)doc->GetCurrentPlayer());
@@ -1110,9 +1016,11 @@ void LSkatApp::PrepareGame(KEMessage *msg)
   msg->AddData(QCString("Sc2"),(short)doc->GetScore(1));
   msg->AddData(QCString("Level"),(short)doc->GetComputerLevel());
 }
+
 void LSkatApp::ExtractGame(KEMessage *msg)
 {
-  if (!msg) return ;
+  if (!msg)
+    return;
   // Do we have to switch players?
   bool switchit;
   short remote;
@@ -1165,9 +1073,4 @@ void LSkatApp::SetGrafix(QString s)
   mGrafix=s;
 }
 
-void LSkatApp::slotKeyBindings()
-{
-  KKeyDialog::configure(actionCollection(), this);
-}
-
 #include "lskat.moc"
